import { __extends } from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { IgxFinancialIndicatorComponent } from "./igx-financial-indicator-component";
import { IgxFinancialSeriesComponent } from "./igx-financial-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { FullStochasticOscillatorIndicator } from "./FullStochasticOscillatorIndicator";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent Full Stochastic Oscillator indicator series.
 * Default required members: High, Low, Close
*
* The `FullStochasticOscillatorIndicator` class represents a IgxDataChartComponent Full Stochastic Oscillator indicator series.
*
* ```html
* <igx-data-chart  #chart
*     [dataSource]="data">
*     <igx-category-x-axis
*     label="label"
*     #xAxis
*     >
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
*     minimumValue="0"
*     #yAxis>
*     </igx-numeric-y-axis>
*     <igx-full-stochastic-oscillator-indicator
*     [xAxis]="xAxis"
*     [yAxis]="yAxis"
*     openMemberPath="open"
*     highMemberPath="high"
*     lowMemberPath="low"
*     closeMemberPath="close">
* </gx-full-stochastic-oscillator-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxFullStochasticOscillatorIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
var IgxFullStochasticOscillatorIndicatorComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgxFullStochasticOscillatorIndicatorComponent, _super);
    function IgxFullStochasticOscillatorIndicatorComponent() {
        return _super.call(this) || this;
    }
    IgxFullStochasticOscillatorIndicatorComponent.prototype.createImplementation = function () {
        return new FullStochasticOscillatorIndicator();
    };
    Object.defineProperty(IgxFullStochasticOscillatorIndicatorComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxFullStochasticOscillatorIndicatorComponent.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current FullStochasticOscillatorIndicator object.
         * The typical, and initial, value for FullStochasticOscillatorIndicator periods is 14.
        *
        * You can use the `period` property for the moving average period of the current FullStochasticOscillatorIndicator object.
        *
        * ```html
        * <igx-data-chart  #chart
        *     [dataSource]="data">
        *     <igx-category-x-axis
        *     label="label"
        *     #xAxis
        *     >
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *     minimumValue="0"
        *     #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-full-stochastic-oscillator-indicator
        *     [xAxis]="xAxis"
        *     [yAxis]="yAxis"
        *     openMemberPath="open"
        *     highMemberPath="high"
        *     lowMemberPath="low"
        *     closeMemberPath="close"
        * 	period=30>
        * </gx-full-stochastic-oscillator-indicator>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.series.period = 30;
        * ```
        */
        get: function () {
            return this.i.va;
        },
        set: function (v) {
            this.i.va = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxFullStochasticOscillatorIndicatorComponent.prototype, "smoothingPeriod", {
        /**
         * Gets or sets the moving average SmoothingPeriod for the current FullStochasticOscillatorIndicator object.
         * The typical, and initial, value for FullStochasticOscillatorIndicator SmoothingPeriod is 3.
        *
        * The `SmoothingPeriod` property to fets/sets the moving average SmoothingPeriod for the current FullStochasticOscillatorIndicator object.
        *
        * ```html
        * <igx-data-chart  #chart
        *     [dataSource]="data">
        *     <igx-category-x-axis
        *     label="label"
        *     #xAxis
        *     >
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *     minimumValue="0"
        *     #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-full-stochastic-oscillator-indicator
        *     [xAxis]="xAxis"
        *     [yAxis]="yAxis"
        *     openMemberPath="open"
        *     highMemberPath="high"
        *     lowMemberPath="low"
        *     closeMemberPath="close"
        * 	[smoothingPeriod]=30>
        * </gx-full-stochastic-oscillator-indicator>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * series.smoothingPeriod=30;
        * ```
        */
        get: function () {
            return this.i.smoothingPeriod;
        },
        set: function (v) {
            this.i.smoothingPeriod = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxFullStochasticOscillatorIndicatorComponent.prototype, "triggerPeriod", {
        /**
         * Gets or sets the moving average TriggerPeriod for the current FullStochasticOscillatorIndicator object.
         * The typical, and initial, value for FullStochasticOscillatorIndicator TriggerPeriod is 3.
        *
        * You can use the `period` to set the current moving average period.
        *
        * ```html
        * <igx-data-chart  #chart
        *     [dataSource]="data">
        *     <igx-category-x-axis
        *     label="label"
        *     #xAxis
        *     >
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *     minimumValue="0"
        *     #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-full-stochastic-oscillator-indicator
        *     [xAxis]="xAxis"
        *     [yAxis]="yAxis"
        *     openMemberPath="open"
        *     highMemberPath="high"
        *     lowMemberPath="low"
        *     closeMemberPath="close"
        * 	[triggerPeriod]=30>
        * </gx-full-stochastic-oscillator-indicator>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.series.triggerPeriod = 30;
        * ```
        */
        get: function () {
            return this.i.vc;
        },
        set: function (v) {
            this.i.vc = +v;
        },
        enumerable: false,
        configurable: true
    });
    IgxFullStochasticOscillatorIndicatorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxFullStochasticOscillatorIndicatorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxFullStochasticOscillatorIndicatorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: IgxFullStochasticOscillatorIndicatorComponent, selector: "igx-full-stochastic-oscillator-indicator", inputs: { period: "period", smoothingPeriod: "smoothingPeriod", triggerPeriod: "triggerPeriod" }, providers: [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(function () { return IgxFullStochasticOscillatorIndicatorComponent; }) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(function () { return IgxFullStochasticOscillatorIndicatorComponent; }) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(function () { return IgxFullStochasticOscillatorIndicatorComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxFullStochasticOscillatorIndicatorComponent; }) }], usesInheritance: true, ngImport: i0, template: "", isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
    return IgxFullStochasticOscillatorIndicatorComponent;
}(IgxStrategyBasedIndicatorComponent));
export { IgxFullStochasticOscillatorIndicatorComponent };
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: IgxFullStochasticOscillatorIndicatorComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'igx-full-stochastic-oscillator-indicator',
                    template: "",
                    providers: [{ provide: IgxStrategyBasedIndicatorComponent, useExisting: forwardRef(function () { return IgxFullStochasticOscillatorIndicatorComponent; }) }, { provide: IgxFinancialIndicatorComponent, useExisting: forwardRef(function () { return IgxFullStochasticOscillatorIndicatorComponent; }) }, { provide: IgxFinancialSeriesComponent, useExisting: forwardRef(function () { return IgxFullStochasticOscillatorIndicatorComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxFullStochasticOscillatorIndicatorComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { period: [{
                type: Input
            }], smoothingPeriod: [{
                type: Input
            }], triggerPeriod: [{
                type: Input
            }] } });
