import { UnknownValuePlotting } from "igniteui-angular-core";
import { IgxHorizontalAnchoredCategorySeriesComponent } from "./igx-horizontal-anchored-category-series-component";
import { AreaSeries } from "./AreaSeries";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent area series.
 * Displays trend over time or ordered categories.
 * Useful when there are many data points and the order is important.
*
* The `AreaSeries` class represents a IgxDataChartComponent area series.Displays trend over time or ordered categories.
*
* Useful when there are many data points and the order is important.
*
* ```html
* <igx-data-chart #chart
*     [dataSource]="data">
*     <igx-category-x-axis
*         label="label"
*         #xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
*         #yAxis>
*     </igx-numeric-y-axis>
*     <igx-area-series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         valueMemberPath="value"  >
*     </igx-area-series>
* </igx-data-chart>
* ```
*
* ```ts
* let series: IgxAreaSeriesComponent = new IgxAreaSeriesComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.valueMemberPath = "Value";
* this.chart.series.add(series);
* ```
*/
export declare class IgxAreaSeriesComponent extends IgxHorizontalAnchoredCategorySeriesComponent {
    protected createImplementation(): AreaSeries;
    /**
                                 * @hidden
                                 */
    get i(): AreaSeries;
    constructor();
    /**
     * Gets whether the current series shows an area or line shape.
    *
    * The `IsAreaOrLine` is used to check if the current series shows an area or line shape.
    *
    * ```ts
    * let series: IgxAreaSeriesComponent = new IgxAreaSeriesComponent();
    * let x= series.isAreaOrLine;
    * ```
    */
    get isAreaOrLine(): boolean;
    static ngAcceptInputType_isAreaOrLine: boolean | string;
    /**
     * Gets whether the current series shows an area shape.
    */
    get isArea(): boolean;
    static ngAcceptInputType_isArea: boolean | string;
    /**
     * Determines how unknown values will be plotted on the chart.
     * Null and Double.NaN are two examples of unknown values.
    *
    * The `unknownValuePlotting` property is used to determines how unknown values will be plotted on the chart.
    *
    * Null and Double.NaN are two examples of unknown values.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-area-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    * 		unknownValuePlotting="DontPlot"  >
    *     </igx-area-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * series.unknownValuePlotting = UnknownValuePlotting.LinearInterpolate;
    * ```
    */
    get unknownValuePlotting(): UnknownValuePlotting;
    set unknownValuePlotting(v: UnknownValuePlotting);
    static ngAcceptInputType_unknownValuePlotting: UnknownValuePlotting | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxAreaSeriesComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxAreaSeriesComponent, "igx-area-series", never, { "unknownValuePlotting": "unknownValuePlotting"; }, {}, never, never>;
}
