import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { ChaikinOscillatorIndicator } from "./ChaikinOscillatorIndicator";
import * as i0 from "@angular/core";
/**
 * Represents the IgxDataChartComponent Chaikin Oscillator indicator series.
 * Default required members: Close, Low, High, Volume
*
* `ChaikinOscillatorIndicator` class specify the series as Chaikin Oscillator Indicator series.
*
* ```html
* <igx-data-chart [dataSource]="data">
*   <igx-category-x-axis #xAxis
*     label="time">
*   </igx-category-x-axis>
*   <igx-numeric-y-axis #yAxis>
*   </igx-numeric-y-axis>
*   <igx-chaikin-oscillator-indicator
*     [xAxis]="xAxis"
*     [yAxis]="yAxis"
*     openMemberPath="open"
*     highMemberPath="high"
*     lowMemberPath="low"
*     closeMemberPath="close"
*     volumeMemberPath="volume"
*     longPeriod="30">
*   </igx-chaikin-oscillator-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxChaikinOscillatorIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export declare class IgxChaikinOscillatorIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    protected createImplementation(): ChaikinOscillatorIndicator;
    /**
                                 * @hidden
                                 */
    get i(): ChaikinOscillatorIndicator;
    constructor();
    /**
     * Gets or sets the short moving average period for the current ChaikinOscillatorIndicator object.
     * The typical, and initial, value for short CHO periods is 3.
    *
    * Set the `ShortPeriod` property if you wish to change the short moving average period for the indicator.
    *
    * ```html
    * <igx-data-chart [dataSource]="data">
    *   <igx-category-x-axis #xAxis
    *     label="time">
    *   </igx-category-x-axis>
    *   <igx-numeric-y-axis #yAxis>
    *   </igx-numeric-y-axis>
    *
    *   <igx-chaikin-oscillator-indicator
    *     [xAxis]="xAxis"
    *     [yAxis]="yAxis"
    *     openMemberPath="open"
    *     highMemberPath="high"
    *     lowMemberPath="low"
    *     closeMemberPath="close"
    *     volumeMemberPath="volume"
    *     shortPeriod="5">
    *   </igx-chaikin-oscillator-indicator>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.shortPeriod = 30;
    * ```
    */
    get shortPeriod(): number;
    set shortPeriod(v: number);
    static ngAcceptInputType_shortPeriod: number | string;
    /**
     * Gets or sets the long moving average period for the current ChaikinOscillatorIndicator object.
     * The typical, and initial, value for long CHO periods is 10.
    *
    * Set the `LongPeriod` property if you wish to change the long moving average period for the indicator.
    *
    * ```html
    * <igx-data-chart [dataSource]="data">
    *   <igx-category-x-axis #xAxis
    *     label="time">
    *   </igx-category-x-axis>
    *   <igx-numeric-y-axis #yAxis>
    *   </igx-numeric-y-axis>
    *
    *   <igx-chaikin-oscillator-indicator
    *     [xAxis]="xAxis"
    *     [yAxis]="yAxis"
    *     openMemberPath="open"
    *     highMemberPath="high"
    *     lowMemberPath="low"
    *     closeMemberPath="close"
    *     volumeMemberPath="volume"
    *     longPeriod="30" >
    *   </igx-chaikin-oscillator-indicator>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.longPeriod = 30;
    * ```
    */
    get longPeriod(): number;
    set longPeriod(v: number);
    static ngAcceptInputType_longPeriod: number | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxChaikinOscillatorIndicatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxChaikinOscillatorIndicatorComponent, "igx-chaikin-oscillator-indicator", never, { "shortPeriod": "shortPeriod"; "longPeriod": "longPeriod"; }, {}, never, never>;
}
