import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { ChaikinVolatilityIndicator } from "./ChaikinVolatilityIndicator";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent Chaikin Volatility indicator series.
 * The ChaikinVolatility indicator attempts to show volatility by displaying the spread between
 * the high and low values.
 * Default required members: High, Low
*
* `ChaikinVolatilityIndicator` class specify the series as Chaikin Volitility Indicator series.
*
* ```html
* <igx-data-chart [dataSource]="data">
*   <igx-category-x-axis #xAxis
*     label="time">
*   </igx-category-x-axis>
*   <igx-numeric-y-axis #yAxis>
*   </igx-numeric-y-axis>
*
*   <igx-chaikin-volatility-indicator
*     [xAxis]="xAxis"
*     [yAxis]="yAxis"
*     openMemberPath="open"
*     highMemberPath="high"
*     lowMemberPath="low"
*     closeMemberPath="close"
*     volumeMemberPath="volume"   >
*   </igx-chaikin-volatility-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxChaikinVolatilityIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export declare class IgxChaikinVolatilityIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    protected createImplementation(): ChaikinVolatilityIndicator;
    /**
                                 * @hidden
                                 */
    get i(): ChaikinVolatilityIndicator;
    constructor();
    /**
     * Gets or sets the moving average period for the current ChaikinVolatilityIndicator object.
     * The typical, and initial, value for ChaikinVolatilityIndicator periods is 10.
    *
    * Set the `Period` property if you wish to change the moving average period for the indicator.
    *
    * ```html
    * <igx-data-chart [dataSource]="data">
    *   <igx-category-x-axis #xAxis
    *     label="time">
    *   </igx-category-x-axis>
    *   <igx-numeric-y-axis #yAxis>
    *   </igx-numeric-y-axis>
    *
    *   <igx-chaikin-volatility-indicator
    *     [xAxis]="xAxis"
    *     [yAxis]="yAxis"
    *     openMemberPath="open"
    *     highMemberPath="high"
    *     lowMemberPath="low"
    *     closeMemberPath="close"
    *     volumeMemberPath="volume"
    *     period="30">
    *   </igx-chaikin-volatility-indicator>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.longPeriod = 30;
    * ```
    */
    get period(): number;
    set period(v: number);
    static ngAcceptInputType_period: number | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxChaikinVolatilityIndicatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxChaikinVolatilityIndicatorComponent, "igx-chaikin-volatility-indicator", never, { "period": "period"; }, {}, never, never>;
}
