import { TemplateRef, EventEmitter, OnInit } from '@angular/core';
import { IgRect } from "igniteui-angular-core";
import { HorizontalAlignment } from "igniteui-angular-core";
import { UnknownValuePlotting } from "igniteui-angular-core";
import { TrendLineType } from "igniteui-angular-core";
import { IgxChartSeriesEventArgs } from './igx-chart-series-event-args';
import { DomainChart } from "./DomainChart";
import { IgxDomainChartSeriesPointerEventArgs } from './igx-domain-chart-series-pointer-event-args';
import { IgxMarkerTypeCollection } from './igx-marker-type-collection';
import { ToolTipType } from "./ToolTipType";
import { CrosshairsDisplayMode } from "./CrosshairsDisplayMode";
import { IgxCalloutStyleUpdatingEventArgs } from "./igx-callout-style-updating-event-args";
import { ComputedPlotAreaMarginMode } from './ComputedPlotAreaMarginMode';
import { SeriesHighlightingMode } from './SeriesHighlightingMode';
import { SeriesHighlightingBehavior } from './SeriesHighlightingBehavior';
import { LegendHighlightingMode } from './LegendHighlightingMode';
import { SeriesOutlineMode } from './SeriesOutlineMode';
import { MarkerOutlineMode } from './MarkerOutlineMode';
import { MarkerFillMode } from './MarkerFillMode';
import { MarkerAutomaticBehavior } from './MarkerAutomaticBehavior';
import { LegendItemBadgeMode } from "igniteui-angular-core";
import { LegendItemBadgeShape } from "igniteui-angular-core";
import { DomainType } from "./DomainType";
import { DataAbbreviationMode } from "igniteui-angular-core";
import { DataLegendValueMode } from "igniteui-angular-core";
import { DataLegendHeaderDateMode } from "igniteui-angular-core";
import { DataLegendHeaderTimeMode } from "igniteui-angular-core";
import { DataLegendUnitsMode } from "igniteui-angular-core";
import { DataLegendLabelMode } from "igniteui-angular-core";
import { DataLegendSummaryType } from "igniteui-angular-core";
import { SeriesPlotAreaMarginHorizontalMode } from './SeriesPlotAreaMarginHorizontalMode';
import { SeriesPlotAreaMarginVerticalMode } from './SeriesPlotAreaMarginVerticalMode';
import { IgxCalloutPlacementPositionsCollection } from './igx-callout-placement-positions-collection';
import { SeriesViewerScrollbarMode } from './SeriesViewerScrollbarMode';
import { SeriesViewerHorizontalScrollbarPosition } from './SeriesViewerHorizontalScrollbarPosition';
import { SeriesViewerVerticalScrollbarPosition } from './SeriesViewerVerticalScrollbarPosition';
import { IgxCalloutRenderStyleUpdatingEventArgs } from './igx-callout-render-style-updating-event-args';
import { DataToolTipLayerGroupingMode } from "igniteui-angular-core";
import { DataTooltipGroupedPositionX } from "igniteui-angular-core";
import { DataTooltipGroupedPositionY } from "igniteui-angular-core";
import { IgxChartSummaryDescriptionCollection } from './igx-chart-summary-description-collection';
import { IgxChartSortDescriptionCollection } from './igx-chart-sort-description-collection';
import { IgxFilterExpressionCollection } from "igniteui-angular-core";
import { ICommandAvailabilityListener } from "igniteui-angular-core";
import { ICommandStateChangedListener } from "igniteui-angular-core";
import { IgxValueModeCollection } from './igx-value-mode-collection';
import { ToolCommand } from "igniteui-angular-core";
import { ToolActionInfo } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents a base class for all domain charts that can plot scatter data and shapefiles
*
* ```html
* <igx-category-chart
*       yAxisMinimumValue="0"
*       [dataSource]="data"
*       bottomMargin= 20>
*     </igx-category-chart>
* ```
*/
export declare abstract class IgxDomainChartComponent implements OnInit {
    protected createImplementation(): DomainChart;
    ngOnInit(): void;
    protected _implementation: any;
    get i(): DomainChart;
    protected onImplementationCreated(): void;
    constructor();
    /**
    * Sets or gets the template reference to use for tooltips for all the series.
    *
    *
    */
    get tooltipTemplate(): TemplateRef<any>;
    set tooltipTemplate(v: TemplateRef<any>);
    /**
    * Sets or gets the template references to use for tooltips for all the series, in order.
    *
    *
    */
    get tooltipTemplates(): TemplateRef<any>[];
    set tooltipTemplates(v: TemplateRef<any>[]);
    get legend(): any;
    set legend(v: any);
    private _calloutsDataSource;
    set calloutsDataSource(value: Array<any>);
    get calloutsDataSource(): Array<any>;
    bindCalloutsData(): void;
    /**
 * Gets or sets the scaling value used to affect the pixel density of the control.
 * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
 * to appear blurry.
*/
    get pixelScalingRatio(): number;
    set pixelScalingRatio(v: number);
    static ngAcceptInputType_pixelScalingRatio: number | string;
    /**
     * Gets or sets the left margin of chart title
    *
    *  Use `titleLeftMargin` property for the left margin of chart title.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    * 	titleLeftMargin= 10>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.titleLeftMargin = 10;
    * ```
    */
    get titleLeftMargin(): number;
    set titleLeftMargin(v: number);
    static ngAcceptInputType_titleLeftMargin: number | string;
    /**
     * Gets or sets the right margin of chart title
    *
    *  Use `titleLeftMargin` property for the right margin of chart title.
    *
    * ```html
    * <igx-category-chart
    * 		yAxisMinimumValue="0"
    * 		[dataSource]="data"
    * 		titleRightMargin= 10>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.titleRightMargin = 10;
    * ```
    */
    get titleRightMargin(): number;
    set titleRightMargin(v: number);
    static ngAcceptInputType_titleRightMargin: number | string;
    /**
     * Gets or sets the top margin of chart title
    *
    *  Use `titleTopMargin` property for the top margin of chart title.
    *
    * ```html
    * <igx-category-chart
    *      yAxisMinimumValue="0"
    *      [dataSource]="data"
    *      title="Countries"
    *      titleTopMargin=10 >
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.titleTopMargin = 10;
    * ```
    */
    get titleTopMargin(): number;
    set titleTopMargin(v: number);
    static ngAcceptInputType_titleTopMargin: number | string;
    /**
     * Gets or sets the bottom margin of chart title
    *
    *  Use `titleBottomMargin` property for the bottom margin of chart title.
    *
    * ```html
    * <igx-category-chart
    *    yAxisMinimumValue="0"
    *    [dataSource]="data"
    *    titleBottomMargin= 10 >
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.titleBottomMargin = 5;
    * ```
    */
    get titleBottomMargin(): number;
    set titleBottomMargin(v: number);
    static ngAcceptInputType_titleBottomMargin: number | string;
    /**
     * Gets or sets the left margin of chart subtitle
    *
    * Use `subtitleLeftMargin` property for the left margin of chart subtitle.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     subtitleLeftMargin= 20>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.subtitleLeftMargin = 20 ;
    * ```
    */
    get subtitleLeftMargin(): number;
    set subtitleLeftMargin(v: number);
    static ngAcceptInputType_subtitleLeftMargin: number | string;
    /**
     * Gets or sets the top margin of chart subtitle
    *
    * Use `subtitleTopMargin` property for the top margin of chart subtitle.
    *
    * ```html
    *    <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       subtitle= "This is a subtitle"
    *       subtitleTopMargin=10>
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.subtitleTopMargin = 10;
    * ```
    */
    get subtitleTopMargin(): number;
    set subtitleTopMargin(v: number);
    static ngAcceptInputType_subtitleTopMargin: number | string;
    /**
     * Gets or sets the right margin of chart subtitle
    *
    * Use `subtitleRightMargin` property for the right margin of chart subtitle.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     subtitleRightMargin= 10>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.subtitleRightMargin = 20 ;
    * ```
    */
    get subtitleRightMargin(): number;
    set subtitleRightMargin(v: number);
    static ngAcceptInputType_subtitleRightMargin: number | string;
    /**
     * Gets or sets the bottom margin of chart subtitle
    *
    * Use `subtitleBottomMargin` property for the bottom margin of chart subtitle.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    * 	subtitleBottomMargin=10>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.subtitleBottomMargin = 10 ;
    * ```
    */
    get subtitleBottomMargin(): number;
    set subtitleBottomMargin(v: number);
    static ngAcceptInputType_subtitleBottomMargin: number | string;
    /**
     * Gets or sets color of chart subtitle
    *
    * Use `subtitleTextColor` property to color the subtitle.
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       subtitle= "This is a subtitle"
    *       subtitleTextColor= 'blue'>
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.subtitleTextColor = "#ff0000" ;
    * ```
    */
    get subtitleTextColor(): string;
    set subtitleTextColor(v: string);
    /**
     * Gets or sets color of chart title
    *
    *  Use `titleTextColor` property to color the chart title
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       titleTextColor= "red">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.titleTextColor="red" ;
    * ```
    */
    get titleTextColor(): string;
    set titleTextColor(v: string);
    /**
     * Gets or sets the left margin of the chart content.
    *
    * Use the 'leftMargin' property for the left margin of the chart content.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       leftMargin=20>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.leftMargin = 20;
    * ```
    */
    get leftMargin(): number;
    set leftMargin(v: number);
    static ngAcceptInputType_leftMargin: number | string;
    /**
     * Gets or sets the top margin of the chart content.
    *
    * Use `topMargin` property for the margin of the chart content.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     topMargin= 20>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.topMargin=20;
    * ```
    */
    get topMargin(): number;
    set topMargin(v: number);
    static ngAcceptInputType_topMargin: number | string;
    /**
     * Gets or sets the right margin of the chart content.
    *
    * Use `rightMargin` property for the right margin of the chart content.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     rightMargin=20>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *   this.chart.rightMargin = 20 ;
    * ```
    */
    get rightMargin(): number;
    set rightMargin(v: number);
    static ngAcceptInputType_rightMargin: number | string;
    /**
     * Gets or sets the bottom margin around the chart content.
    *
    * Use the `bottomMargin` property for the bottom margin around the chart content.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       bottomMargin= 20>
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.bottomMargin=20;
    * ```
    */
    get bottomMargin(): number;
    set bottomMargin(v: number);
    static ngAcceptInputType_bottomMargin: number | string;
    /**
     * Gets or sets the duration used for animating series plots when the data is changing
    *
    * Use the `TransitionDuration` property to animating between data values.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     transitionDuration="500">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.transitionDuratio= 500;
    * ```
    */
    get transitionDuration(): number;
    set transitionDuration(v: number);
    static ngAcceptInputType_transitionDuration: number | string;
    /**
     * Gets or sets the easing function used for animating series plots when the data is changing.
     * This can be set to one of the known values "linear" or "cubic," or it can be set to an easing function which takes a single numeric parameter and returns a number.
    *
    * The 'transitionInEasingFunction' property used for easing function for animating series plots when the chart is loading into view.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     transitionInEasingFunction= "cubic">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.transitionInEasingFunction=  this.cubicFunc;
    *
    * cubicFunc(time: number) : number
    *   {
    *     return time;
    *   }
    * ```
    */
    get transitionEasingFunction(): (time: number) => number;
    set transitionEasingFunction(v: (time: number) => number);
    /**
     * Gets or sets CSS font property for the chart subtitle
    *
    * Use `subtitleTextStyle` property for the CSS font of the chart subtitle.
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       subtitle= "This is a subtitle"
    *       subtitleTextStyle ="16pt Verdona">
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.subtitleTextStyle= "16pt Verdona";
    * ```
    */
    get subtitleTextStyle(): string;
    set subtitleTextStyle(v: string);
    /**
     * Gets or sets CSS font property for the chart title
    *
    * Use `titleTextStyle` property for the CSS font property of the chart title
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       titleTextStyle= "24pt Verdona">
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.xAxisTitleTextStyle = "24pt Verdona";
    * ```
    */
    get titleTextStyle(): string;
    set titleTextStyle(v: string);
    get dataToolTipGroupingMode(): DataToolTipLayerGroupingMode;
    set dataToolTipGroupingMode(v: DataToolTipLayerGroupingMode);
    static ngAcceptInputType_dataToolTipGroupingMode: DataToolTipLayerGroupingMode | string;
    /**
     * Gets or sets the offset of the tooltip layer on the X axis.
    */
    get dataToolTipPositionOffsetX(): number;
    set dataToolTipPositionOffsetX(v: number);
    static ngAcceptInputType_dataToolTipPositionOffsetX: number | string;
    /**
     * Gets or sets the offset of the tooltip layer on the Y axis.
    */
    get dataToolTipPositionOffsetY(): number;
    set dataToolTipPositionOffsetY(v: number);
    static ngAcceptInputType_dataToolTipPositionOffsetY: number | string;
    /**
     * Gets or sets the offset of the tooltip layer on the X axis.
    */
    get dataToolTipDefaultPositionOffsetX(): number;
    set dataToolTipDefaultPositionOffsetX(v: number);
    static ngAcceptInputType_dataToolTipDefaultPositionOffsetX: number | string;
    /**
     * Gets or sets the offset of the tooltip layer on the Y axis.
    */
    get dataToolTipDefaultPositionOffsetY(): number;
    set dataToolTipDefaultPositionOffsetY(v: number);
    static ngAcceptInputType_dataToolTipDefaultPositionOffsetY: number | string;
    /**
     * Gets or sets the tooltip position mode on the X axis for grouped series.
    */
    get dataToolTipGroupedPositionModeX(): DataTooltipGroupedPositionX;
    set dataToolTipGroupedPositionModeX(v: DataTooltipGroupedPositionX);
    static ngAcceptInputType_dataToolTipGroupedPositionModeX: DataTooltipGroupedPositionX | string;
    /**
     * Gets or sets the tooltip position mode on the Y axis for grouped series.
    */
    get dataToolTipGroupedPositionModeY(): DataTooltipGroupedPositionY;
    set dataToolTipGroupedPositionModeY(v: DataTooltipGroupedPositionY);
    static ngAcceptInputType_dataToolTipGroupedPositionModeY: DataTooltipGroupedPositionY | string;
    /**
     * Gets or sets whether the data legend should update when the series data is mutated.
    */
    get dataToolTipShouldUpdateWhenSeriesDataChanges(): boolean;
    set dataToolTipShouldUpdateWhenSeriesDataChanges(v: boolean);
    static ngAcceptInputType_dataToolTipShouldUpdateWhenSeriesDataChanges: boolean | string;
    /**
     * Gets or sets indexes or names of series to include in displaying in the data legend, e.g. "0, 1"
    */
    get dataToolTipIncludedSeries(): string[];
    set dataToolTipIncludedSeries(v: string[]);
    static ngAcceptInputType_dataToolTipIncludedSeries: string[] | string;
    /**
     * Gets or sets indexes or names of series to exclude from displaying in the data legend, e.g. "0, 1"
     * The ExcludedSeries property takes precedences over values of IncludedSeries property
    */
    get dataToolTipExcludedSeries(): string[];
    set dataToolTipExcludedSeries(v: string[]);
    static ngAcceptInputType_dataToolTipExcludedSeries: string[] | string;
    /**
     * Gets or sets names of data columns or their labels to include in displaying in the data legend, e.g. "High, Low" or "H, L"
     * The ExcludedColumns property takes precedences over values of IncludedColumns property
    */
    get dataToolTipIncludedColumns(): string[];
    set dataToolTipIncludedColumns(v: string[]);
    static ngAcceptInputType_dataToolTipIncludedColumns: string[] | string;
    /**
     * Gets or sets names of data columns or their labels to exclude from displaying in the data legend, e.g. "High, Low" or "H, L"
     * The ExcludedColumns property takes precedences over values of IncludedColumns property
    */
    get dataToolTipExcludedColumns(): string[];
    set dataToolTipExcludedColumns(v: string[]);
    static ngAcceptInputType_dataToolTipExcludedColumns: string[] | string;
    /**
     * Gets or sets mode for abbreviating large numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get dataToolTipValueFormatAbbreviation(): DataAbbreviationMode;
    set dataToolTipValueFormatAbbreviation(v: DataAbbreviationMode);
    static ngAcceptInputType_dataToolTipValueFormatAbbreviation: DataAbbreviationMode | string;
    /**
     * Gets or sets maximum digits for formating numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get dataToolTipValueFormatMaxFractions(): number;
    set dataToolTipValueFormatMaxFractions(v: number);
    static ngAcceptInputType_dataToolTipValueFormatMaxFractions: number | string;
    /**
     * Gets or sets minimum digits for formating numbers displayed in the legend
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get dataToolTipValueFormatMinFractions(): number;
    set dataToolTipValueFormatMinFractions(v: number);
    static ngAcceptInputType_dataToolTipValueFormatMinFractions: number | string;
    /**
     * Gets or sets the mode for displaying values in the data legend, e.g. Currency ($500.25), Decimal (500.25), Integer (500)
    */
    get dataToolTipValueFormatMode(): DataLegendValueMode;
    set dataToolTipValueFormatMode(v: DataLegendValueMode);
    static ngAcceptInputType_dataToolTipValueFormatMode: DataLegendValueMode | string;
    /**
     * Gets or sets globalization culture when displaying values as currencies, e.g. use "en-GB" to display British pound symbol when the ValueFormatMode property is set to 'Currency' mode
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get dataToolTipValueFormatCulture(): string;
    set dataToolTipValueFormatCulture(v: string);
    /**
     * Gets or sets whether or not use grouping separator, e.g, 15,000 for 15000
     * This property is ignored when setting ValueFormatSpecifiers or ValueFormatString properties
    */
    get dataToolTipValueFormatUseGrouping(): boolean;
    set dataToolTipValueFormatUseGrouping(v: boolean);
    static ngAcceptInputType_dataToolTipValueFormatUseGrouping: boolean | string;
    /**
     * Gets or sets the format string for values displayed in the data legend.
    */
    get dataToolTipValueFormatString(): string;
    set dataToolTipValueFormatString(v: string);
    /**
     * Gets or sets the format specifiers to use with the ValueFormatString string.
    */
    get dataToolTipValueFormatSpecifiers(): any[];
    set dataToolTipValueFormatSpecifiers(v: any[]);
    static ngAcceptInputType_dataToolTipValueFormatSpecifiers: any[] | string;
    get dataToolTipValueRowMarginBottom(): number;
    set dataToolTipValueRowMarginBottom(v: number);
    static ngAcceptInputType_dataToolTipValueRowMarginBottom: number | string;
    get dataToolTipValueRowMarginLeft(): number;
    set dataToolTipValueRowMarginLeft(v: number);
    static ngAcceptInputType_dataToolTipValueRowMarginLeft: number | string;
    get dataToolTipValueRowMarginRight(): number;
    set dataToolTipValueRowMarginRight(v: number);
    static ngAcceptInputType_dataToolTipValueRowMarginRight: number | string;
    get dataToolTipValueRowMarginTop(): number;
    set dataToolTipValueRowMarginTop(v: number);
    static ngAcceptInputType_dataToolTipValueRowMarginTop: number | string;
    ensureDataToolTipValueRowMargin(): void;
    /**
     * Gets or sets whether to show series rows.
    */
    get dataToolTipValueRowVisible(): boolean;
    set dataToolTipValueRowVisible(v: boolean);
    static ngAcceptInputType_dataToolTipValueRowVisible: boolean | string;
    /**
     * Gets or sets text displayed when data column is missing a value, e.g. "no data"
    */
    get dataToolTipValueTextWhenMissingData(): string;
    set dataToolTipValueTextWhenMissingData(v: string);
    /**
     * Gets or sets whether to use series colors when displaying values in the legend
    */
    get dataToolTipValueTextUseSeriesColors(): boolean;
    set dataToolTipValueTextUseSeriesColors(v: boolean);
    static ngAcceptInputType_dataToolTipValueTextUseSeriesColors: boolean | string;
    get dataToolTipValueTextMarginBottom(): number;
    set dataToolTipValueTextMarginBottom(v: number);
    static ngAcceptInputType_dataToolTipValueTextMarginBottom: number | string;
    get dataToolTipValueTextMarginLeft(): number;
    set dataToolTipValueTextMarginLeft(v: number);
    static ngAcceptInputType_dataToolTipValueTextMarginLeft: number | string;
    get dataToolTipValueTextMarginRight(): number;
    set dataToolTipValueTextMarginRight(v: number);
    static ngAcceptInputType_dataToolTipValueTextMarginRight: number | string;
    get dataToolTipValueTextMarginTop(): number;
    set dataToolTipValueTextMarginTop(v: number);
    static ngAcceptInputType_dataToolTipValueTextMarginTop: number | string;
    ensureDataToolTipValueTextMargin(): void;
    /**
     * Gets or sets the units text color.
    */
    get dataToolTipValueTextColor(): string;
    set dataToolTipValueTextColor(v: string);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get dataToolTipValueTextStyle(): string;
    set dataToolTipValueTextStyle(v: string);
    /**
     * Gets or sets the format string for header text displayed in the data legend.
    */
    get dataToolTipHeaderFormatString(): string;
    set dataToolTipHeaderFormatString(v: string);
    /**
     * Gets or sets the format specifiers to use with the HeaderFormatString string.
    */
    get dataToolTipHeaderFormatSpecifiers(): any[];
    set dataToolTipHeaderFormatSpecifiers(v: any[]);
    static ngAcceptInputType_dataToolTipHeaderFormatSpecifiers: any[] | string;
    /**
     * Gets or sets globalization culture when displaying header as date time
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get dataToolTipHeaderFormatCulture(): string;
    set dataToolTipHeaderFormatCulture(v: string);
    /**
     * Gets or sets date format for the header
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get dataToolTipHeaderFormatDate(): DataLegendHeaderDateMode;
    set dataToolTipHeaderFormatDate(v: DataLegendHeaderDateMode);
    static ngAcceptInputType_dataToolTipHeaderFormatDate: DataLegendHeaderDateMode | string;
    /**
     * Gets or sets time format for the header
     * This property is ignored when setting HeaderFormatSpecifiers or HeaderFormatString properties
    */
    get dataToolTipHeaderFormatTime(): DataLegendHeaderTimeMode;
    set dataToolTipHeaderFormatTime(v: DataLegendHeaderTimeMode);
    static ngAcceptInputType_dataToolTipHeaderFormatTime: DataLegendHeaderTimeMode | string;
    /**
     * Gets or sets the HeaderText for the data legend.
    */
    get dataToolTipHeaderText(): string;
    set dataToolTipHeaderText(v: string);
    /**
     * Gets or sets the header text color.
    */
    get dataToolTipHeaderTextColor(): string;
    set dataToolTipHeaderTextColor(v: string);
    get dataToolTipHeaderTextMarginBottom(): number;
    set dataToolTipHeaderTextMarginBottom(v: number);
    static ngAcceptInputType_dataToolTipHeaderTextMarginBottom: number | string;
    get dataToolTipHeaderTextMarginLeft(): number;
    set dataToolTipHeaderTextMarginLeft(v: number);
    static ngAcceptInputType_dataToolTipHeaderTextMarginLeft: number | string;
    get dataToolTipHeaderTextMarginRight(): number;
    set dataToolTipHeaderTextMarginRight(v: number);
    static ngAcceptInputType_dataToolTipHeaderTextMarginRight: number | string;
    get dataToolTipHeaderTextMarginTop(): number;
    set dataToolTipHeaderTextMarginTop(v: number);
    static ngAcceptInputType_dataToolTipHeaderTextMarginTop: number | string;
    ensureDataToolTipHeaderTextMargin(): void;
    get dataToolTipHeaderRowMarginBottom(): number;
    set dataToolTipHeaderRowMarginBottom(v: number);
    static ngAcceptInputType_dataToolTipHeaderRowMarginBottom: number | string;
    get dataToolTipHeaderRowMarginLeft(): number;
    set dataToolTipHeaderRowMarginLeft(v: number);
    static ngAcceptInputType_dataToolTipHeaderRowMarginLeft: number | string;
    get dataToolTipHeaderRowMarginRight(): number;
    set dataToolTipHeaderRowMarginRight(v: number);
    static ngAcceptInputType_dataToolTipHeaderRowMarginRight: number | string;
    get dataToolTipHeaderRowMarginTop(): number;
    set dataToolTipHeaderRowMarginTop(v: number);
    static ngAcceptInputType_dataToolTipHeaderRowMarginTop: number | string;
    ensureDataToolTipHeaderRowMargin(): void;
    /**
     * Gets or sets whether to show Header row.
    */
    get dataToolTipHeaderRowVisible(): boolean;
    set dataToolTipHeaderRowVisible(v: boolean);
    static ngAcceptInputType_dataToolTipHeaderRowVisible: boolean | string;
    /**
     * Gets or Sets the style to use for the header text.
    */
    get dataToolTipHeaderTextStyle(): string;
    set dataToolTipHeaderTextStyle(v: string);
    /**
     * Gets or sets the summary text color.
    */
    get dataToolTipSummaryTitleTextColor(): string;
    set dataToolTipSummaryTitleTextColor(v: string);
    /**
     * Gets or Sets the style to use for the summary text.
    */
    get dataToolTipSummaryTitleTextStyle(): string;
    set dataToolTipSummaryTitleTextStyle(v: string);
    /**
     * Gets or sets the SummaryType for the data legend.
    */
    get dataToolTipSummaryType(): DataLegendSummaryType;
    set dataToolTipSummaryType(v: DataLegendSummaryType);
    static ngAcceptInputType_dataToolTipSummaryType: DataLegendSummaryType | string;
    /**
     * Gets or sets the SummaryTitleText for the data legend.
    */
    get dataToolTipSummaryTitleText(): string;
    set dataToolTipSummaryTitleText(v: string);
    get dataToolTipSummaryTitleTextMarginBottom(): number;
    set dataToolTipSummaryTitleTextMarginBottom(v: number);
    static ngAcceptInputType_dataToolTipSummaryTitleTextMarginBottom: number | string;
    get dataToolTipSummaryTitleTextMarginLeft(): number;
    set dataToolTipSummaryTitleTextMarginLeft(v: number);
    static ngAcceptInputType_dataToolTipSummaryTitleTextMarginLeft: number | string;
    get dataToolTipSummaryTitleTextMarginRight(): number;
    set dataToolTipSummaryTitleTextMarginRight(v: number);
    static ngAcceptInputType_dataToolTipSummaryTitleTextMarginRight: number | string;
    get dataToolTipSummaryTitleTextMarginTop(): number;
    set dataToolTipSummaryTitleTextMarginTop(v: number);
    static ngAcceptInputType_dataToolTipSummaryTitleTextMarginTop: number | string;
    ensureDataToolTipSummaryTitleTextMargin(): void;
    get dataToolTipSummaryRowMarginBottom(): number;
    set dataToolTipSummaryRowMarginBottom(v: number);
    static ngAcceptInputType_dataToolTipSummaryRowMarginBottom: number | string;
    get dataToolTipSummaryRowMarginLeft(): number;
    set dataToolTipSummaryRowMarginLeft(v: number);
    static ngAcceptInputType_dataToolTipSummaryRowMarginLeft: number | string;
    get dataToolTipSummaryRowMarginRight(): number;
    set dataToolTipSummaryRowMarginRight(v: number);
    static ngAcceptInputType_dataToolTipSummaryRowMarginRight: number | string;
    get dataToolTipSummaryRowMarginTop(): number;
    set dataToolTipSummaryRowMarginTop(v: number);
    static ngAcceptInputType_dataToolTipSummaryRowMarginTop: number | string;
    ensureDataToolTipSummaryRowMargin(): void;
    /**
     * Gets or sets the units text color.
    */
    get dataToolTipSummaryValueTextColor(): string;
    set dataToolTipSummaryValueTextColor(v: string);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get dataToolTipSummaryValueTextStyle(): string;
    set dataToolTipSummaryValueTextStyle(v: string);
    /**
     * Gets or sets the units text for the data legend.
    */
    get dataToolTipSummaryLabelText(): string;
    set dataToolTipSummaryLabelText(v: string);
    /**
     * Gets or sets the units text color.
    */
    get dataToolTipSummaryLabelTextColor(): string;
    set dataToolTipSummaryLabelTextColor(v: string);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get dataToolTipSummaryLabelTextStyle(): string;
    set dataToolTipSummaryLabelTextStyle(v: string);
    /**
     * Gets or sets the units text for the data legend.
    */
    get dataToolTipSummaryUnitsText(): string;
    set dataToolTipSummaryUnitsText(v: string);
    /**
     * Gets or sets the units text color.
    */
    get dataToolTipSummaryUnitsTextColor(): string;
    set dataToolTipSummaryUnitsTextColor(v: string);
    /**
     * Gets or Sets the style to use for the units text.
    */
    get dataToolTipSummaryUnitsTextStyle(): string;
    set dataToolTipSummaryUnitsTextStyle(v: string);
    get dataToolTipBadgeMarginBottom(): number;
    set dataToolTipBadgeMarginBottom(v: number);
    static ngAcceptInputType_dataToolTipBadgeMarginBottom: number | string;
    get dataToolTipBadgeMarginLeft(): number;
    set dataToolTipBadgeMarginLeft(v: number);
    static ngAcceptInputType_dataToolTipBadgeMarginLeft: number | string;
    get dataToolTipBadgeMarginRight(): number;
    set dataToolTipBadgeMarginRight(v: number);
    static ngAcceptInputType_dataToolTipBadgeMarginRight: number | string;
    get dataToolTipBadgeMarginTop(): number;
    set dataToolTipBadgeMarginTop(v: number);
    static ngAcceptInputType_dataToolTipBadgeMarginTop: number | string;
    ensureDataToolTipBadgeMargin(): void;
    /**
     * Gets or sets the BadgeShape for the data legend.
    */
    get dataToolTipBadgeShape(): LegendItemBadgeShape;
    set dataToolTipBadgeShape(v: LegendItemBadgeShape);
    static ngAcceptInputType_dataToolTipBadgeShape: LegendItemBadgeShape | string;
    /**
     * Gets or sets the UnitsMode for the data legend.
    */
    get dataToolTipUnitsDisplayMode(): DataLegendUnitsMode;
    set dataToolTipUnitsDisplayMode(v: DataLegendUnitsMode);
    static ngAcceptInputType_dataToolTipUnitsDisplayMode: DataLegendUnitsMode | string;
    /**
     * Gets or sets the units text for the data legend.
    */
    get dataToolTipUnitsText(): string;
    set dataToolTipUnitsText(v: string);
    /**
     * Gets or sets the units text color.
    */
    get dataToolTipUnitsTextColor(): string;
    set dataToolTipUnitsTextColor(v: string);
    get dataToolTipUnitsTextMarginBottom(): number;
    set dataToolTipUnitsTextMarginBottom(v: number);
    static ngAcceptInputType_dataToolTipUnitsTextMarginBottom: number | string;
    get dataToolTipUnitsTextMarginLeft(): number;
    set dataToolTipUnitsTextMarginLeft(v: number);
    static ngAcceptInputType_dataToolTipUnitsTextMarginLeft: number | string;
    get dataToolTipUnitsTextMarginRight(): number;
    set dataToolTipUnitsTextMarginRight(v: number);
    static ngAcceptInputType_dataToolTipUnitsTextMarginRight: number | string;
    get dataToolTipUnitsTextMarginTop(): number;
    set dataToolTipUnitsTextMarginTop(v: number);
    static ngAcceptInputType_dataToolTipUnitsTextMarginTop: number | string;
    ensureDataToolTipUnitsTextMargin(): void;
    /**
     * Gets or Sets the style to use for the units text.
    */
    get dataToolTipUnitsTextStyle(): string;
    set dataToolTipUnitsTextStyle(v: string);
    get dataToolTipTitleTextMarginBottom(): number;
    set dataToolTipTitleTextMarginBottom(v: number);
    static ngAcceptInputType_dataToolTipTitleTextMarginBottom: number | string;
    get dataToolTipTitleTextMarginLeft(): number;
    set dataToolTipTitleTextMarginLeft(v: number);
    static ngAcceptInputType_dataToolTipTitleTextMarginLeft: number | string;
    get dataToolTipTitleTextMarginRight(): number;
    set dataToolTipTitleTextMarginRight(v: number);
    static ngAcceptInputType_dataToolTipTitleTextMarginRight: number | string;
    get dataToolTipTitleTextMarginTop(): number;
    set dataToolTipTitleTextMarginTop(v: number);
    static ngAcceptInputType_dataToolTipTitleTextMarginTop: number | string;
    ensureDataToolTipTitleTextMargin(): void;
    /**
     * Gets or sets the display text color.
    */
    get dataToolTipTitleTextColor(): string;
    set dataToolTipTitleTextColor(v: string);
    /**
     * Gets or Sets the style to use for the display text.
    */
    get dataToolTipTitleTextStyle(): string;
    set dataToolTipTitleTextStyle(v: string);
    /**
     * Gets or sets the mode for displaying labels before series values in the data legend, e.g. O: H: L: C: for financial series
    */
    get dataToolTipLabelDisplayMode(): DataLegendLabelMode;
    set dataToolTipLabelDisplayMode(v: DataLegendLabelMode);
    static ngAcceptInputType_dataToolTipLabelDisplayMode: DataLegendLabelMode | string;
    /**
     * Gets or sets the units text color.
    */
    get dataToolTipLabelTextColor(): string;
    set dataToolTipLabelTextColor(v: string);
    get dataToolTipLabelTextMarginBottom(): number;
    set dataToolTipLabelTextMarginBottom(v: number);
    static ngAcceptInputType_dataToolTipLabelTextMarginBottom: number | string;
    get dataToolTipLabelTextMarginLeft(): number;
    set dataToolTipLabelTextMarginLeft(v: number);
    static ngAcceptInputType_dataToolTipLabelTextMarginLeft: number | string;
    get dataToolTipLabelTextMarginRight(): number;
    set dataToolTipLabelTextMarginRight(v: number);
    static ngAcceptInputType_dataToolTipLabelTextMarginRight: number | string;
    get dataToolTipLabelTextMarginTop(): number;
    set dataToolTipLabelTextMarginTop(v: number);
    static ngAcceptInputType_dataToolTipLabelTextMarginTop: number | string;
    ensureDataToolTipLabelTextMargin(): void;
    /**
     * Gets or Sets the style to use for the units text.
    */
    get dataToolTipLabelTextStyle(): string;
    set dataToolTipLabelTextStyle(v: string);
    /**
     * Gets the domain type of this chart
    */
    get domainType(): DomainType;
    static ngAcceptInputType_domainType: DomainType | string;
    /**
     * Gets the current sort that is applied to the grid. Collection can be updated to modify the sort for the grid. Once sort descriptions are in this collection, the grid will no longer listen for changes on their properties.
    */
    get sortDescriptions(): IgxChartSortDescriptionCollection;
    get groupSortDescriptions(): IgxChartSortDescriptionCollection;
    /**
     * Gets the current grouping that is applied to the grid. Collection can be updated to modify the grouping for the grid. Once grouping descriptions are in this collection, the grid will no longer listen for changes on their properties.
    */
    get groupDescriptions(): IgxChartSortDescriptionCollection;
    /**
     * Gets the current filter that is applied to the grid. Collection can be updated to modify the filter for the grid. Once filter expresisons are in this collection, the grid will no longer listen for changes on their properties.
    */
    get filterExpressions(): IgxFilterExpressionCollection;
    /**
     * Gets the current summaries that are applied to the grid.
    */
    get summaryDescriptions(): IgxChartSummaryDescriptionCollection;
    /**
     * Gets the initial sorts that are applied to the chart.
    */
    get initialSortDescriptions(): IgxChartSortDescriptionCollection;
    /**
     * Gets the initial sorts that are applied to the chart after groupings and summaries are applied.
    */
    get initialGroupSortDescriptions(): IgxChartSortDescriptionCollection;
    /**
     * Gets the initial groupings that are applied to the chart.
    */
    get initialGroupDescriptions(): IgxChartSortDescriptionCollection;
    /**
     * Gets the initial summaries that are applied to the chart.
    */
    get initialSummaryDescriptions(): IgxChartSummaryDescriptionCollection;
    /**
     * Gets or sets the sorts to apply to the chart. This property will become ignored if sorts are changed outside of this property.
    */
    get initialSorts(): string;
    set initialSorts(v: string);
    /**
     * Gets or sets the sorts to apply after grouping has been applied.
    */
    get groupSorts(): string;
    set groupSorts(v: string);
    /**
     * Gets or sets the groupings to apply to the chart. This property will become ignored if sorts are changed outside of this property.
    */
    get initialGroups(): string;
    set initialGroups(v: string);
    /**
     * Gets or sets the summaries to apply to the chart. This property will become ignored if sorts are changed outside of this property.
    */
    get initialSummaries(): string;
    set initialSummaries(v: string);
    /**
     * Gets or sets a set of property paths that should be included for consideration by the category chart, leaving the remainder excluded. If null, all properties will be considered.
    *
    * The `IncludedProperties` property used to include the properties for the consideration of the category chart.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     includedProperties="ProductName,Cost" >
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.includedProperties = ["ProductName", "Cost"];
    * ```
    */
    get includedProperties(): string[];
    set includedProperties(v: string[]);
    static ngAcceptInputType_includedProperties: string[] | string;
    /**
     * Gets or sets a set of property paths that should be excluded from consideration by the category chart.
    *
    * The `ExcludedProperties` property used for the property paths that should be excluded from consideration by the category chart.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     excludedProperties="ID">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.excludedProperties = ["ID", "Discount"];
    * ```
    */
    get excludedProperties(): string[];
    set excludedProperties(v: string[]);
    static ngAcceptInputType_excludedProperties: string[] | string;
    /**
     * Gets or sets the palette of brushes to use for coloring the chart series.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    *
    * Use the `Brushes` property to  set the brushes.
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       Brushes="#ff0000, #cc0000, #aa0000">
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.brushes = ["#ff0000","#00ff00"];
    * ```
    */
    get brushes(): string[];
    set brushes(v: string[]);
    static ngAcceptInputType_brushes: string[] | string;
    /**
     * Gets or sets the palette of brushes to use for outlines on the chart series.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    *
    *  Use the `Outlines` property to sets the palette of brushes to use for outlines on the chart series
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     outlines="#ff0000, #cc0000, #aa0000">
    * </igx-category-chart>
    * ```
    */
    get outlines(): string[];
    set outlines(v: string[]);
    static ngAcceptInputType_outlines: string[] | string;
    /**
     * Gets the actual palette of brushes to use for coloring the chart series.
    */
    get actualBrushes(): string[];
    set actualBrushes(v: string[]);
    static ngAcceptInputType_actualBrushes: string[] | string;
    /**
     * Gets the actual palette of brushes to use for outlines on the chart series.
    */
    get actualOutlines(): string[];
    set actualOutlines(v: string[]);
    static ngAcceptInputType_actualOutlines: string[] | string;
    /**
     * Gets or sets whether the chart can be horizontally zoomed through user interactions.
    *
    * Use the `IsHorizontalZoomEnabled` property to allow chart horizontally zoomed .
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       isHorizontalZoomEnabled=true>
    *   </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.isHorizontalZoomEnabled = true;
    * ```
    */
    get isHorizontalZoomEnabled(): boolean;
    set isHorizontalZoomEnabled(v: boolean);
    static ngAcceptInputType_isHorizontalZoomEnabled: boolean | string;
    /**
     * Gets or sets whether the chart can be vertically zoomed through user interactions.
    *
    * Use the `IsVerticalZoomEnabled` property to allow chart zoom vertically.
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       isVerticalZoomEnabled=true>
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.isVerticalZoomEnabled = true;
    * ```
    */
    get isVerticalZoomEnabled(): boolean;
    set isVerticalZoomEnabled(v: boolean);
    static ngAcceptInputType_isVerticalZoomEnabled: boolean | string;
    /**
     * Gets or sets whether the chart should display mock data when the data source has not been provided, if supported for this type of chart.
    */
    get shouldDisplayMockData(): boolean;
    set shouldDisplayMockData(v: boolean);
    static ngAcceptInputType_shouldDisplayMockData: boolean | string;
    /**
     * Gets or sets whether the chart should use a faded skeleton style for mock data.
    */
    get shouldUseSkeletonStyleForMockData(): boolean;
    set shouldUseSkeletonStyleForMockData(v: boolean);
    static ngAcceptInputType_shouldUseSkeletonStyleForMockData: boolean | string;
    /**
     * Gets or sets whether the chart can highlight series through user interactions.
     * This property applies to Category Chart and Financial Chart controls.
    */
    get isSeriesHighlightingEnabled(): boolean;
    set isSeriesHighlightingEnabled(v: boolean);
    static ngAcceptInputType_isSeriesHighlightingEnabled: boolean | string;
    /**
     * Gets or sets the rectangle representing the current scroll and zoom state of the chart.
     * WindowRect is expressed as a Rectangle with coordinates and sizes between 0 and 1.
    *
    * Use `WindowRect` property representing the current scroll and zoom state of the chart.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       WindowRect=[0,0,1,1]>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.windowRect =[0,0,1,1];
    * ```
    */
    get windowRect(): IgRect;
    set windowRect(v: IgRect);
    static ngAcceptInputType_windowRect: IgRect | string;
    /**
     * Gets a rectangle representing the bounds of the plot area.
    *
    * `viewport` property representing the bounds of the plot area.
    *
    * ```ts
    * let viewport:Rect =  this.chart.viewport;
    * ```
    */
    get viewport(): IgRect;
    static ngAcceptInputType_viewport: IgRect | string;
    /**
     * Gets or sets text to display above the plot area.
    *
    * Use the `Title` property to display the text above the plot area.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     title="This is a Title">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.title= "This is a Title";
    * ```
    */
    get chartTitle(): string;
    set chartTitle(v: string);
    /**
     * Gets or sets text to display below the Title, above the plot area.
    *
    * Use the `Subtitle` property to display the text below  and above the plot area.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     subtitle= "This is a subtitle">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.subtitle ="CategoryChart Subtitle" ;
    * ```
    */
    get subtitle(): string;
    set subtitle(v: string);
    /**
     * Gets or sets horizontal alignment which determines the title position, relative to the left and right edges of the control.
    *
    * Use the `TitleAlignment` property for the horizontal alignment of the title.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     titleAlignment= "center">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.titleAlignment = HorizontalAlignment.Center;
    * ```
    */
    get titleAlignment(): HorizontalAlignment;
    set titleAlignment(v: HorizontalAlignment);
    static ngAcceptInputType_titleAlignment: HorizontalAlignment | string;
    /**
     * Gets or sets horizontal alignment which determines the subtitle position, relative to the left and right edges of the control.
    *
    * Use the `SubtitleAlignment` property to Gets or sets horizontal alignment.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     subtitleAlignment= "center">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.subtitleAlignment = HorizontalAlignment.Right;
    * ```
    */
    get subtitleAlignment(): HorizontalAlignment;
    set subtitleAlignment(v: HorizontalAlignment);
    static ngAcceptInputType_subtitleAlignment: HorizontalAlignment | string;
    /**
     * Gets or sets the behavior that determines how unknown values will be plotted on the chart.
     * Null and Double.NaN are two examples of unknown values.
    *
    * Use the `UnknownValuePlotting` property to determines the behavior that how unknown values will be plotted on the chart.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       unknownValuePlotting= "dontPlot">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.unknownValuePlotting =UnknownValuePlotting.DontPlot;
    * ```
    */
    get unknownValuePlotting(): UnknownValuePlotting;
    set unknownValuePlotting(v: UnknownValuePlotting);
    static ngAcceptInputType_unknownValuePlotting: UnknownValuePlotting | string;
    /**
     * Gets or sets the rendering resolution for all series in this chart.
     * Where n = Resolution, for every n horizontal pixels, combine all items into a single data point.  When Resolution = 0, all data points will be rendered as graphical objects.  Charts with a higher resolution will have faster performance.
    *
    * Use the `Resolution` property if the callouts should be display.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     resolution= 2>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *   this.chart.resolution = 2 ;
    * ```
    */
    get resolution(): number;
    set resolution(v: number);
    static ngAcceptInputType_resolution: number | string;
    /**
     * Gets or sets the thickness for all series in this chart. Depending on the ChartType, this can be the main brush used, or just the outline.
    *
    * Use the `Thickness` property for the thickness of all the series in this chart.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     thickness=5>
    * </igx-category-chart>
    * ```
    */
    get thickness(): number;
    set thickness(v: number);
    static ngAcceptInputType_thickness: number | string;
    /**
     * Gets or sets the OutlineMode for all series in this chart.
    */
    get outlineMode(): SeriesOutlineMode;
    set outlineMode(v: SeriesOutlineMode);
    static ngAcceptInputType_outlineMode: SeriesOutlineMode | string;
    /**
     * Gets or sets the MarkerOutlineMode for all series that support markers in this chart.
    */
    get markerOutlineMode(): MarkerOutlineMode;
    set markerOutlineMode(v: MarkerOutlineMode);
    static ngAcceptInputType_markerOutlineMode: MarkerOutlineMode | string;
    /**
     * Gets or sets the MarkerFillMode for all series that support markers in this chart.
    */
    get markerFillMode(): MarkerFillMode;
    set markerFillMode(v: MarkerFillMode);
    static ngAcceptInputType_markerFillMode: MarkerFillMode | string;
    /**
     * Gets or sets the Marker Fill Opacity for all series that support markers in this chart.
    */
    get markerFillOpacity(): number;
    set markerFillOpacity(v: number);
    static ngAcceptInputType_markerFillOpacity: number | string;
    /**
     * Gets or sets the Marker Thickness for all series that support markers in this chart.
    */
    get markerThickness(): number;
    set markerThickness(v: number);
    static ngAcceptInputType_markerThickness: number | string;
    private _markerTypes;
    /**
     * Gets or sets the marker shapes used for indicating location of data points in this chart.
     * This property applies only to these chart types: point, line, spline, bubble, and polygon
    */
    get markerTypes(): IgxMarkerTypeCollection;
    set markerTypes(v: IgxMarkerTypeCollection);
    static ngAcceptInputType_markerTypes: IgxMarkerTypeCollection | string;
    /**
     * Gets or sets the default marker type for all series plotted in this chart.
     * This property is ignored when the MarkerTypes property is set
    */
    get markerAutomaticBehavior(): MarkerAutomaticBehavior;
    set markerAutomaticBehavior(v: MarkerAutomaticBehavior);
    static ngAcceptInputType_markerAutomaticBehavior: MarkerAutomaticBehavior | string;
    /**
     * Gets or sets the palette of brushes used for rendering fill area of data point markers.
     * This property applies only to these chart types: point, line, spline, bubble, and polygon
    *
    * `MarkerBrushes` property used for rendering fill area of data point markers.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     markerBrushes="#ff0000, #cc0000, #aa0000">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.markerBrushes=[ "#ff0000", "#ffff00", "#00ffff" ];
    * ```
    */
    get markerBrushes(): string[];
    set markerBrushes(v: string[]);
    static ngAcceptInputType_markerBrushes: string[] | string;
    /**
     * Gets or sets the palette of brushes used for rendering outlines of data point markers.
     * This property applies only to these chart types: point, line, spline, bubble, and polygon
    *
    * `MarkerOutlines` property used for rendering outlines of data point markers.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     markerOutlines="#ff0000, #cc0000, #aa0000">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.markerOutlines= ["#ff0000", "#ffff00", "#00ffff"] ;
    * ```
    */
    get markerOutlines(): string[];
    set markerOutlines(v: string[]);
    static ngAcceptInputType_markerOutlines: string[] | string;
    /**
     * Gets or sets the maximum number of markers displayed in the plot area of the chart.
    *
    * `markerMaxCount` property used to display maximum number of markers in the plot area of the chart.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     markerMaxCount=100 >
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.markerMaxCount = 100 ;
    * ```
    */
    get markerMaxCount(): number;
    set markerMaxCount(v: number);
    static ngAcceptInputType_markerMaxCount: number | string;
    /**
     * Gets or sets the fill opacity for all series that have area visuals in this chart.
     * For example, Area, SplineArea, Column chart types
    */
    get areaFillOpacity(): number;
    set areaFillOpacity(v: number);
    static ngAcceptInputType_areaFillOpacity: number | string;
    /**
     * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
    */
    get animateSeriesWhenAxisRangeChanges(): boolean;
    set animateSeriesWhenAxisRangeChanges(v: boolean);
    static ngAcceptInputType_animateSeriesWhenAxisRangeChanges: boolean | string;
    /**
     * Gets or sets the palette of brushes to used for coloring trend lines in this chart.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    *
    * Use the `TrendLineBrushes` property for coloring trend lines in the chart.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     trendLineBrushes="#ff0000,#aa0000">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.trendLineBrushes=["#ff0000", "#ffff00", "#00ffff"]	;
    * ```
    */
    get trendLineBrushes(): string[];
    set trendLineBrushes(v: string[]);
    static ngAcceptInputType_trendLineBrushes: string[] | string;
    /**
     * Gets or sets the formula used for calculating trend lines in this chart.
     * This property applies only to these chart types: point, line, spline, and bubble
    *
    * Use the `TrendLineType` property for calculating trend lines.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       trendLineType= "cubicFit">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.trendLineType = TrendLineType.CubicFit;
    * ```
    */
    get trendLineType(): TrendLineType;
    set trendLineType(v: TrendLineType);
    static ngAcceptInputType_trendLineType: TrendLineType | string;
    /**
     * Gets or sets the thickness of the trend lines in this chart.
     * This property applies only to these chart types: point, line, spline, and bubble
    *
    * Use the `TrendLineThickness` property for the thickness of the trend lines in the chart.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     trendLineThickness= 2>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.trendLineThickness=2;
    * ```
    */
    get trendLineThickness(): number;
    set trendLineThickness(v: number);
    static ngAcceptInputType_trendLineThickness: number | string;
    /**
     * Gets or sets a value indicating whether grid and tick lines are aligned to device pixels.
    *
    * Use `AlignsGridLinesToPixels` propert to indicat whether grid and tick lines are aligned to device pixels.
    *
    * ```html
    * <igx-category-chart
    *     [dataSource]="data"
    *     AlignsGridLinesToPixels="true">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.alignsGridLinesToPixels= true;
    * ```
    */
    get alignsGridLinesToPixels(): boolean;
    set alignsGridLinesToPixels(v: boolean);
    static ngAcceptInputType_alignsGridLinesToPixels: boolean | string;
    /**
     * Margin applied to the Left of the plot area.
    */
    get plotAreaMarginLeft(): number;
    set plotAreaMarginLeft(v: number);
    static ngAcceptInputType_plotAreaMarginLeft: number | string;
    /**
     * Margin applied to the Top of the plot area.
    */
    get plotAreaMarginTop(): number;
    set plotAreaMarginTop(v: number);
    static ngAcceptInputType_plotAreaMarginTop: number | string;
    /**
     * Margin applied to the right of the plot area.
    */
    get plotAreaMarginRight(): number;
    set plotAreaMarginRight(v: number);
    static ngAcceptInputType_plotAreaMarginRight: number | string;
    /**
     * Margin applied below the plot area.
    */
    get plotAreaMarginBottom(): number;
    set plotAreaMarginBottom(v: number);
    static ngAcceptInputType_plotAreaMarginBottom: number | string;
    /**
     * Gets or sets mode to use for automatically calculating the plot area margin.
    */
    get computedPlotAreaMarginMode(): ComputedPlotAreaMarginMode;
    set computedPlotAreaMarginMode(v: ComputedPlotAreaMarginMode);
    static ngAcceptInputType_computedPlotAreaMarginMode: ComputedPlotAreaMarginMode | string;
    /**
     * Gets or sets horizontal mode to use for automatically calculating the plot area margin based ont the series.
    */
    get seriesPlotAreaMarginHorizontalMode(): SeriesPlotAreaMarginHorizontalMode;
    set seriesPlotAreaMarginHorizontalMode(v: SeriesPlotAreaMarginHorizontalMode);
    static ngAcceptInputType_seriesPlotAreaMarginHorizontalMode: SeriesPlotAreaMarginHorizontalMode | string;
    /**
     * Gets or sets vertical mode to use for automatically calculating the plot area margin based ont the series.
    */
    get seriesPlotAreaMarginVerticalMode(): SeriesPlotAreaMarginVerticalMode;
    set seriesPlotAreaMarginVerticalMode(v: SeriesPlotAreaMarginVerticalMode);
    static ngAcceptInputType_seriesPlotAreaMarginVerticalMode: SeriesPlotAreaMarginVerticalMode | string;
    /**
     * Gets or sets the highlighting mode to use for the series in the component, when supported. This takes precedence over the series level IsHightlightingEnabled.
    */
    get highlightingMode(): SeriesHighlightingMode;
    set highlightingMode(v: SeriesHighlightingMode);
    static ngAcceptInputType_highlightingMode: SeriesHighlightingMode | string;
    /**
     * Gets or sets the highlighting Behavior to use for the series in the component, when supported. This takes precedence over the series level IsHightlightingEnabled.
    */
    get highlightingBehavior(): SeriesHighlightingBehavior;
    set highlightingBehavior(v: SeriesHighlightingBehavior);
    static ngAcceptInputType_highlightingBehavior: SeriesHighlightingBehavior | string;
    /**
     * Gets or sets the highlighting mode to use for the legend linked to the component, when supported.
    */
    get legendHighlightingMode(): LegendHighlightingMode;
    set legendHighlightingMode(v: LegendHighlightingMode);
    static ngAcceptInputType_legendHighlightingMode: LegendHighlightingMode | string;
    /**
     * Gets or sets the type of legend badges representing all series displayed in a legend linked to this component
     * This property will be ignored when the LegendItemTemplate or LegendItemBadgeTemplate property is set on a series
    */
    get legendItemBadgeShape(): LegendItemBadgeShape;
    set legendItemBadgeShape(v: LegendItemBadgeShape);
    static ngAcceptInputType_legendItemBadgeShape: LegendItemBadgeShape | string;
    /**
     * Gets or sets the mode of legend badges representing all series displayed in a legend linked to this component.
     * This property will be ignored when the LegendItemTemplate or LegendItemBadgeTemplate property is set on a series
    */
    get legendItemBadgeMode(): LegendItemBadgeMode;
    set legendItemBadgeMode(v: LegendItemBadgeMode);
    static ngAcceptInputType_legendItemBadgeMode: LegendItemBadgeMode | string;
    get trendLinePeriod(): number;
    set trendLinePeriod(v: number);
    static ngAcceptInputType_trendLinePeriod: number | string;
    /**
     * Gets or sets the style of tooltip to be displayed.
    */
    get toolTipType(): ToolTipType;
    set toolTipType(v: ToolTipType);
    static ngAcceptInputType_toolTipType: ToolTipType | string;
    /**
     * Gets or sets the crosshairs to be displayed.
    */
    get crosshairsDisplayMode(): CrosshairsDisplayMode;
    set crosshairsDisplayMode(v: CrosshairsDisplayMode);
    static ngAcceptInputType_crosshairsDisplayMode: CrosshairsDisplayMode | string;
    /**
     * Gets or sets whether crosshairs will snap to the nearest data point.
    */
    get crosshairsSnapToData(): boolean;
    set crosshairsSnapToData(v: boolean);
    static ngAcceptInputType_crosshairsSnapToData: boolean | string;
    /**
     * Gets or sets the color to apply to vertical crosshairs line.
    */
    get crosshairsLineVerticalStroke(): string;
    set crosshairsLineVerticalStroke(v: string);
    /**
     * Gets or sets thickness of crosshairs lines.
    */
    get crosshairsLineThickness(): number;
    set crosshairsLineThickness(v: number);
    static ngAcceptInputType_crosshairsLineThickness: number | string;
    /**
     * Gets or sets the color to apply to horizontal crosshairs line.
    */
    get crosshairsLineHorizontalStroke(): string;
    set crosshairsLineHorizontalStroke(v: string);
    /**
     * Gets or sets whether annotations are shown along the axis for crosshair values
    */
    get crosshairsAnnotationEnabled(): boolean;
    set crosshairsAnnotationEnabled(v: boolean);
    static ngAcceptInputType_crosshairsAnnotationEnabled: boolean | string;
    /**
     * Gets or sets the background of crosshair annotation on x-axis.
    */
    get crosshairsAnnotationXAxisBackground(): string;
    set crosshairsAnnotationXAxisBackground(v: string);
    /**
     * Gets or sets the background of crosshair annotation on y-axis.
    */
    get crosshairsAnnotationYAxisBackground(): string;
    set crosshairsAnnotationYAxisBackground(v: string);
    /**
     * Gets or sets the text color of crosshair annotation on x-axis.
    */
    get crosshairsAnnotationXAxisTextColor(): string;
    set crosshairsAnnotationXAxisTextColor(v: string);
    /**
     * Gets or sets the text color of crosshair annotation on y-axis.
    */
    get crosshairsAnnotationYAxisTextColor(): string;
    set crosshairsAnnotationYAxisTextColor(v: string);
    /**
     * Gets or sets precision on interpolated values of crosshairs on x-axis.
    */
    get crosshairsAnnotationXAxisPrecision(): number;
    set crosshairsAnnotationXAxisPrecision(v: number);
    static ngAcceptInputType_crosshairsAnnotationXAxisPrecision: number | string;
    /**
     * Gets or sets precision on interpolated values of crosshairs on y-axis.
    */
    get crosshairsAnnotationYAxisPrecision(): number;
    set crosshairsAnnotationYAxisPrecision(v: number);
    static ngAcceptInputType_crosshairsAnnotationYAxisPrecision: number | string;
    /**
     * Gets or sets whether annotations for the final value of each series is displayed on the axis.
    */
    get shouldAvoidAxisAnnotationCollisions(): boolean;
    set shouldAvoidAxisAnnotationCollisions(v: boolean);
    static ngAcceptInputType_shouldAvoidAxisAnnotationCollisions: boolean | string;
    /**
     * Gets or sets a whether the chart should pan its content when zooing in passed max zoom level.
    */
    get shouldPanOnMaximumZoom(): boolean;
    set shouldPanOnMaximumZoom(v: boolean);
    static ngAcceptInputType_shouldPanOnMaximumZoom: boolean | string;
    /**
     * Gets or sets whether annotations for the final value of each series is displayed on the axis.
    */
    get finalValueAnnotationsVisible(): boolean;
    set finalValueAnnotationsVisible(v: boolean);
    static ngAcceptInputType_finalValueAnnotationsVisible: boolean | string;
    /**
     * Gets or sets the background of final value annotation.
    */
    get finalValueAnnotationsBackground(): string;
    set finalValueAnnotationsBackground(v: string);
    /**
     * Gets or sets the text color of final value annotation.
    */
    get finalValueAnnotationsTextColor(): string;
    set finalValueAnnotationsTextColor(v: string);
    /**
     * Gets or sets precision on final value annotation.
    */
    get finalValueAnnotationsPrecision(): number;
    set finalValueAnnotationsPrecision(v: number);
    static ngAcceptInputType_finalValueAnnotationsPrecision: number | string;
    /**
     * Gets or sets if the auto value callouts should be displayed.
    */
    get autoCalloutsVisible(): boolean;
    set autoCalloutsVisible(v: boolean);
    static ngAcceptInputType_autoCalloutsVisible: boolean | string;
    /**
     * Gets or sets if callouts should be displayed.
    */
    get calloutsVisible(): boolean;
    set calloutsVisible(v: boolean);
    static ngAcceptInputType_calloutsVisible: boolean | string;
    /**
     * Gets or sets if event annotations should be displayed.
    */
    get calloutStyleUpdatingEventEnabled(): boolean;
    set calloutStyleUpdatingEventEnabled(v: boolean);
    static ngAcceptInputType_calloutStyleUpdatingEventEnabled: boolean | string;
    private _calloutsAllowedPositions;
    /**
     * Gets or sets the allowed positions that the callout layer is allowed to use.
    */
    get calloutsAllowedPositions(): IgxCalloutPlacementPositionsCollection;
    set calloutsAllowedPositions(v: IgxCalloutPlacementPositionsCollection);
    static ngAcceptInputType_calloutsAllowedPositions: IgxCalloutPlacementPositionsCollection | string;
    /**
     * Gets or sets the member path of the X data for the callouts.
    */
    get calloutsXMemberPath(): string;
    set calloutsXMemberPath(v: string);
    /**
     * Gets or sets the member path of the Y data for the callouts.
    */
    get calloutsYMemberPath(): string;
    set calloutsYMemberPath(v: string);
    /**
     * Gets or sets the member path of the label data for the callouts.
    */
    get calloutsLabelMemberPath(): string;
    set calloutsLabelMemberPath(v: string);
    /**
     * Gets or sets the member path of the content data for the callouts.
    */
    get calloutsContentMemberPath(): string;
    set calloutsContentMemberPath(v: string);
    private _valueLines;
    /**
     * Gets or sets what value lines to use in the chart.
    */
    get valueLines(): IgxValueModeCollection;
    set valueLines(v: IgxValueModeCollection);
    static ngAcceptInputType_valueLines: IgxValueModeCollection | string;
    /**
     * Gets or sets the palette of brushes to use for coloring the value lines present in the ValueLines property.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    */
    get valueLinesBrushes(): string[];
    set valueLinesBrushes(v: string[]);
    static ngAcceptInputType_valueLinesBrushes: string[] | string;
    /**
     * Gets or sets thickness of value lines.
    */
    get valueLinesThickness(): number;
    set valueLinesThickness(v: number);
    static ngAcceptInputType_valueLinesThickness: number | string;
    /**
     * Gets or sets the horizontal scrollbar mode to use for the series viewer.
    */
    get horizontalViewScrollbarMode(): SeriesViewerScrollbarMode;
    set horizontalViewScrollbarMode(v: SeriesViewerScrollbarMode);
    static ngAcceptInputType_horizontalViewScrollbarMode: SeriesViewerScrollbarMode | string;
    /**
     * Gets or sets the vertical scrollbar mode to use for the series viewer.
    */
    get verticalViewScrollbarMode(): SeriesViewerScrollbarMode;
    set verticalViewScrollbarMode(v: SeriesViewerScrollbarMode);
    static ngAcceptInputType_verticalViewScrollbarMode: SeriesViewerScrollbarMode | string;
    /**
     * Gets or sets the position to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarPosition(): SeriesViewerHorizontalScrollbarPosition;
    set horizontalViewScrollbarPosition(v: SeriesViewerHorizontalScrollbarPosition);
    static ngAcceptInputType_horizontalViewScrollbarPosition: SeriesViewerHorizontalScrollbarPosition | string;
    /**
     * Gets or sets the position to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarPosition(): SeriesViewerVerticalScrollbarPosition;
    set verticalViewScrollbarPosition(v: SeriesViewerVerticalScrollbarPosition);
    static ngAcceptInputType_verticalViewScrollbarPosition: SeriesViewerVerticalScrollbarPosition | string;
    /**
     * Gets or sets the fill to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarFill(): string;
    set horizontalViewScrollbarFill(v: string);
    /**
     * Gets or sets the outline to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarOutline(): string;
    set horizontalViewScrollbarOutline(v: string);
    /**
     * Gets or sets the stroke thickness to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarStrokeThickness(): number;
    set horizontalViewScrollbarStrokeThickness(v: number);
    static ngAcceptInputType_horizontalViewScrollbarStrokeThickness: number | string;
    /**
     * Gets or sets the max opacity to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarMaxOpacity(): number;
    set horizontalViewScrollbarMaxOpacity(v: number);
    static ngAcceptInputType_horizontalViewScrollbarMaxOpacity: number | string;
    /**
     * Gets or sets the corner radius to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarCornerRadius(): number;
    set horizontalViewScrollbarCornerRadius(v: number);
    static ngAcceptInputType_horizontalViewScrollbarCornerRadius: number | string;
    /**
     * Gets or sets the height to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarHeight(): number;
    set horizontalViewScrollbarHeight(v: number);
    static ngAcceptInputType_horizontalViewScrollbarHeight: number | string;
    /**
     * Gets or sets the inset distance to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarInset(): number;
    set horizontalViewScrollbarInset(v: number);
    static ngAcceptInputType_horizontalViewScrollbarInset: number | string;
    /**
     * Gets or sets the track start inset to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarTrackStartInset(): number;
    set horizontalViewScrollbarTrackStartInset(v: number);
    static ngAcceptInputType_horizontalViewScrollbarTrackStartInset: number | string;
    /**
     * Gets or sets the track end inset to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarTrackEndInset(): number;
    set horizontalViewScrollbarTrackEndInset(v: number);
    static ngAcceptInputType_horizontalViewScrollbarTrackEndInset: number | string;
    /**
     * Gets or sets whether to use automatic track insets for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarShouldAddAutoTrackInsets(): boolean;
    set horizontalViewScrollbarShouldAddAutoTrackInsets(v: boolean);
    static ngAcceptInputType_horizontalViewScrollbarShouldAddAutoTrackInsets: boolean | string;
    /**
     * Gets or sets the fill to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarFill(): string;
    set verticalViewScrollbarFill(v: string);
    /**
     * Gets or sets the outline to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarOutline(): string;
    set verticalViewScrollbarOutline(v: string);
    /**
     * Gets or sets the stroke thickness to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarStrokeThickness(): number;
    set verticalViewScrollbarStrokeThickness(v: number);
    static ngAcceptInputType_verticalViewScrollbarStrokeThickness: number | string;
    /**
     * Gets or sets the max opacity to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarMaxOpacity(): number;
    set verticalViewScrollbarMaxOpacity(v: number);
    static ngAcceptInputType_verticalViewScrollbarMaxOpacity: number | string;
    /**
     * Gets or sets the corner radius to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarCornerRadius(): number;
    set verticalViewScrollbarCornerRadius(v: number);
    static ngAcceptInputType_verticalViewScrollbarCornerRadius: number | string;
    /**
     * Gets or sets the width to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarWidth(): number;
    set verticalViewScrollbarWidth(v: number);
    static ngAcceptInputType_verticalViewScrollbarWidth: number | string;
    /**
     * Gets or sets the inset distance to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarInset(): number;
    set verticalViewScrollbarInset(v: number);
    static ngAcceptInputType_verticalViewScrollbarInset: number | string;
    /**
     * Gets or sets the track start inset to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarTrackStartInset(): number;
    set verticalViewScrollbarTrackStartInset(v: number);
    static ngAcceptInputType_verticalViewScrollbarTrackStartInset: number | string;
    /**
     * Gets or sets the track end inset to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarTrackEndInset(): number;
    set verticalViewScrollbarTrackEndInset(v: number);
    static ngAcceptInputType_verticalViewScrollbarTrackEndInset: number | string;
    /**
     * Gets or sets whether to use automatic track insets for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarShouldAddAutoTrackInsets(): boolean;
    set verticalViewScrollbarShouldAddAutoTrackInsets(v: boolean);
    static ngAcceptInputType_verticalViewScrollbarShouldAddAutoTrackInsets: boolean | string;
    /**
     * Sets or gets the minimum width that the window rect is allowed to reach before being clamped.
     * Decrease this value if you want to allow for further zooming into the viewer.
     * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
     * This property accepts values between 0.0 (max zooming) and 1.0 (no zooming)
    */
    get windowRectMinWidth(): number;
    set windowRectMinWidth(v: number);
    static ngAcceptInputType_windowRectMinWidth: number | string;
    /**
     * Sets or gets the minimum height that the window rect is allowed to reach before being clamped.
     * Decrease this value if you want to allow for further zooming into the viewer.
     * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
     * This property accepts values between 0.0 (max zooming) and 1.0 (no zooming)
    */
    get windowRectMinHeight(): number;
    set windowRectMinHeight(v: number);
    static ngAcceptInputType_windowRectMinHeight: number | string;
    /**
     * Sets or gets minimum pixel width that the window is allowed to reach before being clamped.
     * Decrease this value if you want to allow for further zooming into the viewer.
     * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
     * This property is overridden by the WindowRectMinWidth property
    */
    get windowSizeMinWidth(): number;
    set windowSizeMinWidth(v: number);
    static ngAcceptInputType_windowSizeMinWidth: number | string;
    /**
     * Sets or gets minimum pixel height that the window is allowed to reach before being clamped.
     * Decrease this value if you want to allow for further zooming into the viewer.
     * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
     * This property is overridden by the WindowRectMinHeight property
    */
    get windowSizeMinHeight(): number;
    set windowSizeMinHeight(v: number);
    static ngAcceptInputType_windowSizeMinHeight: number | string;
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Provides a container for this control

*
* `provideContainer` method provide container for the control.
*
* ```ts
*     this.chart.provideContainer("Container");
* ```
*/
    provideContainer(container: any): void;
    /**
     * Destroy this control
    
    *
    * Use the `destroy` property to destroy the chart.
    *
    * ```ts
    * this.chart.destroy();
    * ```
    */
    destroy(): void;
    /**
     * Called when the control has been resized.
    
    *
    * `NotifyResized` method Called when the control has been resized.
    *
    * ```ts
    * this.chart.notifyResized();
    * ```
    */
    notifyResized(): void;
    notifyVisualPropertiesChanged(): void;
    /**
     * Forces any pending refresh to the chart to be finished.
    
    *
    * Method `flush` used to Forces any pending deferred work to render on the chart before continuing.
    *
    * ```ts
    * this.chart.flush();
    * ```
    */
    flush(): void;
    /**
     * Hides the active main tooltip, if displayed.
    
    *
    * Use the `HideToolTip` method to hide the active tooltip.
    *
    * ```ts
    * this.chart.hideToolTip();
    * ```
    */
    hideToolTip(): void;
    /**
     * Replays transition-in animation on all series in the chart.
    
    */
    replayTransitionIn(): void;
    /**
     * Performs zoom in action on the chart by specified percentage of current window rect
    
    */
    zoomIn(percentage: number): void;
    /**
     * Performs zoom out action on the chart by specified percentage of current window rect
    
    */
    zoomOut(percentage: number): void;
    /**
     * Resets the zoom level to default.
    
    */
    resetZoom(): void;
    getDesiredToolbarActions(): ToolActionInfo[];
    onToolCommandExecuting(command: ToolCommand): void;
    addCommandAvailabilityListener(listener: ICommandAvailabilityListener): void;
    removeCommandAvailabilityListener(listener: ICommandAvailabilityListener): void;
    addCommandStateChangedListener(listener: ICommandStateChangedListener): void;
    removeCommandStateChangedListener(listener: ICommandStateChangedListener): void;
    notifySetItem(source_: any, index: number, oldItem: any, newItem: any): void;
    /**
     * Used to manually notify the chart that the data source has reset or cleared its items.
    
    *
    * Use `notifyClearItems` method to notifies the chart that the items have been cleared from an associated data source.
    *
    * ```ts
    * this.chart.notifyClearItems(this.data);
    * ```
    */
    notifyClearItems(source_: any): void;
    notifyInsertItem(source_: any, index: number, newItem: any): void;
    notifyRemoveItem(source_: any, index: number, oldItem: any): void;
    private _seriesAdded;
    /**
     * Event raised when a series is initialized and added to this chart.
    *
    * `SeriesAdded` event raised when a series is initialized and added to this chart.
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       (seriesAdded)="CategoryChart_SeriesAdded()"
    *      >
    * </igx-category-chart>
    * ```
    */
    get seriesAdded(): EventEmitter<{
        sender: any;
        args: IgxChartSeriesEventArgs;
    }>;
    private _seriesRemoved;
    /**
     * Event raised when a series is removed from this chart.
    *
    * `SeriesRemoved` event raised when a series is removed from this chart.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       (seriesRemoved)="CategoryChart_seriesRemoved()">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  CategoryChart_seriesRemoved(sender: any , aregs: ChartSeriesEventArgs)
    *   {
    *
    *   }
    * ```
    */
    get seriesRemoved(): EventEmitter<{
        sender: any;
        args: IgxChartSeriesEventArgs;
    }>;
    private _seriesPointerEnter;
    /**
     * Occurs when the pointer enters a Series.
    *
    * `SeriesPointerEnter` event raised when the pointer enters a Series.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       (seriesPointerEnter)="CategoryChart_seriesPointerEnter()" >
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * CategoryChart_seriesPointerEnter(sender: any , aregs: ChartSeriesEventArgs)
    *   {
    *
    *   }
    * ```
    */
    get seriesPointerEnter(): EventEmitter<{
        sender: any;
        args: IgxDomainChartSeriesPointerEventArgs;
    }>;
    private _seriesPointerLeave;
    /**
     * Occurs when the pointer leaves a Series.
    *
    * `SeriesPointerLeave` event raised when the pointer leaves a Series.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       (seriesPointerLeave)= "CategoryChart_seriesPointerLeave()" >
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * CategoryChart_seriesPointerLeave(sender: any , aregs: ChartSeriesEventArgs)
    *   {
    *
    *   }
    * ```
    */
    get seriesPointerLeave(): EventEmitter<{
        sender: any;
        args: IgxDomainChartSeriesPointerEventArgs;
    }>;
    private _seriesPointerMove;
    /**
     * Occurs when the pointer moves over a Series.
    *
    * `SeriesPointerMove` event raised when the pointer moves over a Series.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *        (seriesPointerMove)="CategoryChart_seriesPointerMove()">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  CategoryChart_seriesPointerMove(sender: any , aregs: ChartSeriesEventArgs)
    *   {
    *
    *   }
    * ```
    */
    get seriesPointerMove(): EventEmitter<{
        sender: any;
        args: IgxDomainChartSeriesPointerEventArgs;
    }>;
    private _seriesPointerDown;
    /**
     * Occurs when the pointer is pressed down over a Series.
    *
    * `SeriesPointerDown` event raised when the pointer is pressed down over a Series
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       (seriesPointerDown)="CategoryChart_seriesPointerDown()" >
    * </igx-category-chart>
    * ```
    */
    get seriesPointerDown(): EventEmitter<{
        sender: any;
        args: IgxDomainChartSeriesPointerEventArgs;
    }>;
    private _seriesPointerUp;
    /**
     * Occurs when the pointer is released over a Series.
    *
    * `SeriesPointerUp` event raised when the pointer is released over a Series.
    *
    * ```ts
    *  CategoryChart_seriesPointerUp(sender: any , aregs: ChartSeriesEventArgs)
    *   {
    *
    *   }
    * ```
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       (seriesPointerUp)="CategoryChart_seriesPointerUp()" >
    * </igx-category-chart>
    * ```
    */
    get seriesPointerUp(): EventEmitter<{
        sender: any;
        args: IgxDomainChartSeriesPointerEventArgs;
    }>;
    private _calloutStyleUpdating;
    /**
     * Occurs when the style of a callout is updated.
    */
    get calloutStyleUpdating(): EventEmitter<{
        sender: any;
        args: IgxCalloutStyleUpdatingEventArgs;
    }>;
    private _calloutRenderStyleUpdating;
    /**
     * Occurs when the style of a callout is updated.
    */
    get calloutRenderStyleUpdating(): EventEmitter<{
        sender: any;
        args: IgxCalloutRenderStyleUpdatingEventArgs;
    }>;
    protected _zoneRunner: (act: () => void) => void;
    protected _runInZone(act: () => void): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxDomainChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxDomainChartComponent, "ng-component", never, { "tooltipTemplate": "tooltipTemplate"; "tooltipTemplates": "tooltipTemplates"; "legend": "legend"; "calloutsDataSource": "calloutsDataSource"; "pixelScalingRatio": "pixelScalingRatio"; "titleLeftMargin": "titleLeftMargin"; "titleRightMargin": "titleRightMargin"; "titleTopMargin": "titleTopMargin"; "titleBottomMargin": "titleBottomMargin"; "subtitleLeftMargin": "subtitleLeftMargin"; "subtitleTopMargin": "subtitleTopMargin"; "subtitleRightMargin": "subtitleRightMargin"; "subtitleBottomMargin": "subtitleBottomMargin"; "subtitleTextColor": "subtitleTextColor"; "titleTextColor": "titleTextColor"; "leftMargin": "leftMargin"; "topMargin": "topMargin"; "rightMargin": "rightMargin"; "bottomMargin": "bottomMargin"; "transitionDuration": "transitionDuration"; "transitionEasingFunction": "transitionEasingFunction"; "subtitleTextStyle": "subtitleTextStyle"; "titleTextStyle": "titleTextStyle"; "dataToolTipGroupingMode": "dataToolTipGroupingMode"; "dataToolTipPositionOffsetX": "dataToolTipPositionOffsetX"; "dataToolTipPositionOffsetY": "dataToolTipPositionOffsetY"; "dataToolTipDefaultPositionOffsetX": "dataToolTipDefaultPositionOffsetX"; "dataToolTipDefaultPositionOffsetY": "dataToolTipDefaultPositionOffsetY"; "dataToolTipGroupedPositionModeX": "dataToolTipGroupedPositionModeX"; "dataToolTipGroupedPositionModeY": "dataToolTipGroupedPositionModeY"; "dataToolTipShouldUpdateWhenSeriesDataChanges": "dataToolTipShouldUpdateWhenSeriesDataChanges"; "dataToolTipIncludedSeries": "dataToolTipIncludedSeries"; "dataToolTipExcludedSeries": "dataToolTipExcludedSeries"; "dataToolTipIncludedColumns": "dataToolTipIncludedColumns"; "dataToolTipExcludedColumns": "dataToolTipExcludedColumns"; "dataToolTipValueFormatAbbreviation": "dataToolTipValueFormatAbbreviation"; "dataToolTipValueFormatMaxFractions": "dataToolTipValueFormatMaxFractions"; "dataToolTipValueFormatMinFractions": "dataToolTipValueFormatMinFractions"; "dataToolTipValueFormatMode": "dataToolTipValueFormatMode"; "dataToolTipValueFormatCulture": "dataToolTipValueFormatCulture"; "dataToolTipValueFormatUseGrouping": "dataToolTipValueFormatUseGrouping"; "dataToolTipValueFormatString": "dataToolTipValueFormatString"; "dataToolTipValueFormatSpecifiers": "dataToolTipValueFormatSpecifiers"; "dataToolTipValueRowMarginBottom": "dataToolTipValueRowMarginBottom"; "dataToolTipValueRowMarginLeft": "dataToolTipValueRowMarginLeft"; "dataToolTipValueRowMarginRight": "dataToolTipValueRowMarginRight"; "dataToolTipValueRowMarginTop": "dataToolTipValueRowMarginTop"; "dataToolTipValueRowVisible": "dataToolTipValueRowVisible"; "dataToolTipValueTextWhenMissingData": "dataToolTipValueTextWhenMissingData"; "dataToolTipValueTextUseSeriesColors": "dataToolTipValueTextUseSeriesColors"; "dataToolTipValueTextMarginBottom": "dataToolTipValueTextMarginBottom"; "dataToolTipValueTextMarginLeft": "dataToolTipValueTextMarginLeft"; "dataToolTipValueTextMarginRight": "dataToolTipValueTextMarginRight"; "dataToolTipValueTextMarginTop": "dataToolTipValueTextMarginTop"; "dataToolTipValueTextColor": "dataToolTipValueTextColor"; "dataToolTipValueTextStyle": "dataToolTipValueTextStyle"; "dataToolTipHeaderFormatString": "dataToolTipHeaderFormatString"; "dataToolTipHeaderFormatSpecifiers": "dataToolTipHeaderFormatSpecifiers"; "dataToolTipHeaderFormatCulture": "dataToolTipHeaderFormatCulture"; "dataToolTipHeaderFormatDate": "dataToolTipHeaderFormatDate"; "dataToolTipHeaderFormatTime": "dataToolTipHeaderFormatTime"; "dataToolTipHeaderText": "dataToolTipHeaderText"; "dataToolTipHeaderTextColor": "dataToolTipHeaderTextColor"; "dataToolTipHeaderTextMarginBottom": "dataToolTipHeaderTextMarginBottom"; "dataToolTipHeaderTextMarginLeft": "dataToolTipHeaderTextMarginLeft"; "dataToolTipHeaderTextMarginRight": "dataToolTipHeaderTextMarginRight"; "dataToolTipHeaderTextMarginTop": "dataToolTipHeaderTextMarginTop"; "dataToolTipHeaderRowMarginBottom": "dataToolTipHeaderRowMarginBottom"; "dataToolTipHeaderRowMarginLeft": "dataToolTipHeaderRowMarginLeft"; "dataToolTipHeaderRowMarginRight": "dataToolTipHeaderRowMarginRight"; "dataToolTipHeaderRowMarginTop": "dataToolTipHeaderRowMarginTop"; "dataToolTipHeaderRowVisible": "dataToolTipHeaderRowVisible"; "dataToolTipHeaderTextStyle": "dataToolTipHeaderTextStyle"; "dataToolTipSummaryTitleTextColor": "dataToolTipSummaryTitleTextColor"; "dataToolTipSummaryTitleTextStyle": "dataToolTipSummaryTitleTextStyle"; "dataToolTipSummaryType": "dataToolTipSummaryType"; "dataToolTipSummaryTitleText": "dataToolTipSummaryTitleText"; "dataToolTipSummaryTitleTextMarginBottom": "dataToolTipSummaryTitleTextMarginBottom"; "dataToolTipSummaryTitleTextMarginLeft": "dataToolTipSummaryTitleTextMarginLeft"; "dataToolTipSummaryTitleTextMarginRight": "dataToolTipSummaryTitleTextMarginRight"; "dataToolTipSummaryTitleTextMarginTop": "dataToolTipSummaryTitleTextMarginTop"; "dataToolTipSummaryRowMarginBottom": "dataToolTipSummaryRowMarginBottom"; "dataToolTipSummaryRowMarginLeft": "dataToolTipSummaryRowMarginLeft"; "dataToolTipSummaryRowMarginRight": "dataToolTipSummaryRowMarginRight"; "dataToolTipSummaryRowMarginTop": "dataToolTipSummaryRowMarginTop"; "dataToolTipSummaryValueTextColor": "dataToolTipSummaryValueTextColor"; "dataToolTipSummaryValueTextStyle": "dataToolTipSummaryValueTextStyle"; "dataToolTipSummaryLabelText": "dataToolTipSummaryLabelText"; "dataToolTipSummaryLabelTextColor": "dataToolTipSummaryLabelTextColor"; "dataToolTipSummaryLabelTextStyle": "dataToolTipSummaryLabelTextStyle"; "dataToolTipSummaryUnitsText": "dataToolTipSummaryUnitsText"; "dataToolTipSummaryUnitsTextColor": "dataToolTipSummaryUnitsTextColor"; "dataToolTipSummaryUnitsTextStyle": "dataToolTipSummaryUnitsTextStyle"; "dataToolTipBadgeMarginBottom": "dataToolTipBadgeMarginBottom"; "dataToolTipBadgeMarginLeft": "dataToolTipBadgeMarginLeft"; "dataToolTipBadgeMarginRight": "dataToolTipBadgeMarginRight"; "dataToolTipBadgeMarginTop": "dataToolTipBadgeMarginTop"; "dataToolTipBadgeShape": "dataToolTipBadgeShape"; "dataToolTipUnitsDisplayMode": "dataToolTipUnitsDisplayMode"; "dataToolTipUnitsText": "dataToolTipUnitsText"; "dataToolTipUnitsTextColor": "dataToolTipUnitsTextColor"; "dataToolTipUnitsTextMarginBottom": "dataToolTipUnitsTextMarginBottom"; "dataToolTipUnitsTextMarginLeft": "dataToolTipUnitsTextMarginLeft"; "dataToolTipUnitsTextMarginRight": "dataToolTipUnitsTextMarginRight"; "dataToolTipUnitsTextMarginTop": "dataToolTipUnitsTextMarginTop"; "dataToolTipUnitsTextStyle": "dataToolTipUnitsTextStyle"; "dataToolTipTitleTextMarginBottom": "dataToolTipTitleTextMarginBottom"; "dataToolTipTitleTextMarginLeft": "dataToolTipTitleTextMarginLeft"; "dataToolTipTitleTextMarginRight": "dataToolTipTitleTextMarginRight"; "dataToolTipTitleTextMarginTop": "dataToolTipTitleTextMarginTop"; "dataToolTipTitleTextColor": "dataToolTipTitleTextColor"; "dataToolTipTitleTextStyle": "dataToolTipTitleTextStyle"; "dataToolTipLabelDisplayMode": "dataToolTipLabelDisplayMode"; "dataToolTipLabelTextColor": "dataToolTipLabelTextColor"; "dataToolTipLabelTextMarginBottom": "dataToolTipLabelTextMarginBottom"; "dataToolTipLabelTextMarginLeft": "dataToolTipLabelTextMarginLeft"; "dataToolTipLabelTextMarginRight": "dataToolTipLabelTextMarginRight"; "dataToolTipLabelTextMarginTop": "dataToolTipLabelTextMarginTop"; "dataToolTipLabelTextStyle": "dataToolTipLabelTextStyle"; "initialSorts": "initialSorts"; "groupSorts": "groupSorts"; "initialGroups": "initialGroups"; "initialSummaries": "initialSummaries"; "includedProperties": "includedProperties"; "excludedProperties": "excludedProperties"; "brushes": "brushes"; "outlines": "outlines"; "actualBrushes": "actualBrushes"; "actualOutlines": "actualOutlines"; "isHorizontalZoomEnabled": "isHorizontalZoomEnabled"; "isVerticalZoomEnabled": "isVerticalZoomEnabled"; "shouldDisplayMockData": "shouldDisplayMockData"; "shouldUseSkeletonStyleForMockData": "shouldUseSkeletonStyleForMockData"; "isSeriesHighlightingEnabled": "isSeriesHighlightingEnabled"; "windowRect": "windowRect"; "chartTitle": "chartTitle"; "subtitle": "subtitle"; "titleAlignment": "titleAlignment"; "subtitleAlignment": "subtitleAlignment"; "unknownValuePlotting": "unknownValuePlotting"; "resolution": "resolution"; "thickness": "thickness"; "outlineMode": "outlineMode"; "markerOutlineMode": "markerOutlineMode"; "markerFillMode": "markerFillMode"; "markerFillOpacity": "markerFillOpacity"; "markerThickness": "markerThickness"; "markerTypes": "markerTypes"; "markerAutomaticBehavior": "markerAutomaticBehavior"; "markerBrushes": "markerBrushes"; "markerOutlines": "markerOutlines"; "markerMaxCount": "markerMaxCount"; "areaFillOpacity": "areaFillOpacity"; "animateSeriesWhenAxisRangeChanges": "animateSeriesWhenAxisRangeChanges"; "trendLineBrushes": "trendLineBrushes"; "trendLineType": "trendLineType"; "trendLineThickness": "trendLineThickness"; "alignsGridLinesToPixels": "alignsGridLinesToPixels"; "plotAreaMarginLeft": "plotAreaMarginLeft"; "plotAreaMarginTop": "plotAreaMarginTop"; "plotAreaMarginRight": "plotAreaMarginRight"; "plotAreaMarginBottom": "plotAreaMarginBottom"; "computedPlotAreaMarginMode": "computedPlotAreaMarginMode"; "seriesPlotAreaMarginHorizontalMode": "seriesPlotAreaMarginHorizontalMode"; "seriesPlotAreaMarginVerticalMode": "seriesPlotAreaMarginVerticalMode"; "highlightingMode": "highlightingMode"; "highlightingBehavior": "highlightingBehavior"; "legendHighlightingMode": "legendHighlightingMode"; "legendItemBadgeShape": "legendItemBadgeShape"; "legendItemBadgeMode": "legendItemBadgeMode"; "trendLinePeriod": "trendLinePeriod"; "toolTipType": "toolTipType"; "crosshairsDisplayMode": "crosshairsDisplayMode"; "crosshairsSnapToData": "crosshairsSnapToData"; "crosshairsLineVerticalStroke": "crosshairsLineVerticalStroke"; "crosshairsLineThickness": "crosshairsLineThickness"; "crosshairsLineHorizontalStroke": "crosshairsLineHorizontalStroke"; "crosshairsAnnotationEnabled": "crosshairsAnnotationEnabled"; "crosshairsAnnotationXAxisBackground": "crosshairsAnnotationXAxisBackground"; "crosshairsAnnotationYAxisBackground": "crosshairsAnnotationYAxisBackground"; "crosshairsAnnotationXAxisTextColor": "crosshairsAnnotationXAxisTextColor"; "crosshairsAnnotationYAxisTextColor": "crosshairsAnnotationYAxisTextColor"; "crosshairsAnnotationXAxisPrecision": "crosshairsAnnotationXAxisPrecision"; "crosshairsAnnotationYAxisPrecision": "crosshairsAnnotationYAxisPrecision"; "shouldAvoidAxisAnnotationCollisions": "shouldAvoidAxisAnnotationCollisions"; "shouldPanOnMaximumZoom": "shouldPanOnMaximumZoom"; "finalValueAnnotationsVisible": "finalValueAnnotationsVisible"; "finalValueAnnotationsBackground": "finalValueAnnotationsBackground"; "finalValueAnnotationsTextColor": "finalValueAnnotationsTextColor"; "finalValueAnnotationsPrecision": "finalValueAnnotationsPrecision"; "autoCalloutsVisible": "autoCalloutsVisible"; "calloutsVisible": "calloutsVisible"; "calloutStyleUpdatingEventEnabled": "calloutStyleUpdatingEventEnabled"; "calloutsAllowedPositions": "calloutsAllowedPositions"; "calloutsXMemberPath": "calloutsXMemberPath"; "calloutsYMemberPath": "calloutsYMemberPath"; "calloutsLabelMemberPath": "calloutsLabelMemberPath"; "calloutsContentMemberPath": "calloutsContentMemberPath"; "valueLines": "valueLines"; "valueLinesBrushes": "valueLinesBrushes"; "valueLinesThickness": "valueLinesThickness"; "horizontalViewScrollbarMode": "horizontalViewScrollbarMode"; "verticalViewScrollbarMode": "verticalViewScrollbarMode"; "horizontalViewScrollbarPosition": "horizontalViewScrollbarPosition"; "verticalViewScrollbarPosition": "verticalViewScrollbarPosition"; "horizontalViewScrollbarFill": "horizontalViewScrollbarFill"; "horizontalViewScrollbarOutline": "horizontalViewScrollbarOutline"; "horizontalViewScrollbarStrokeThickness": "horizontalViewScrollbarStrokeThickness"; "horizontalViewScrollbarMaxOpacity": "horizontalViewScrollbarMaxOpacity"; "horizontalViewScrollbarCornerRadius": "horizontalViewScrollbarCornerRadius"; "horizontalViewScrollbarHeight": "horizontalViewScrollbarHeight"; "horizontalViewScrollbarInset": "horizontalViewScrollbarInset"; "horizontalViewScrollbarTrackStartInset": "horizontalViewScrollbarTrackStartInset"; "horizontalViewScrollbarTrackEndInset": "horizontalViewScrollbarTrackEndInset"; "horizontalViewScrollbarShouldAddAutoTrackInsets": "horizontalViewScrollbarShouldAddAutoTrackInsets"; "verticalViewScrollbarFill": "verticalViewScrollbarFill"; "verticalViewScrollbarOutline": "verticalViewScrollbarOutline"; "verticalViewScrollbarStrokeThickness": "verticalViewScrollbarStrokeThickness"; "verticalViewScrollbarMaxOpacity": "verticalViewScrollbarMaxOpacity"; "verticalViewScrollbarCornerRadius": "verticalViewScrollbarCornerRadius"; "verticalViewScrollbarWidth": "verticalViewScrollbarWidth"; "verticalViewScrollbarInset": "verticalViewScrollbarInset"; "verticalViewScrollbarTrackStartInset": "verticalViewScrollbarTrackStartInset"; "verticalViewScrollbarTrackEndInset": "verticalViewScrollbarTrackEndInset"; "verticalViewScrollbarShouldAddAutoTrackInsets": "verticalViewScrollbarShouldAddAutoTrackInsets"; "windowRectMinWidth": "windowRectMinWidth"; "windowRectMinHeight": "windowRectMinHeight"; "windowSizeMinWidth": "windowSizeMinWidth"; "windowSizeMinHeight": "windowSizeMinHeight"; }, { "seriesAdded": "seriesAdded"; "seriesRemoved": "seriesRemoved"; "seriesPointerEnter": "seriesPointerEnter"; "seriesPointerLeave": "seriesPointerLeave"; "seriesPointerMove": "seriesPointerMove"; "seriesPointerDown": "seriesPointerDown"; "seriesPointerUp": "seriesPointerUp"; "calloutStyleUpdating": "calloutStyleUpdating"; "calloutRenderStyleUpdating": "calloutRenderStyleUpdating"; }, never, never>;
}
