import { IndicatorDisplayType } from "./IndicatorDisplayType";
import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { ForceIndexIndicator } from "./ForceIndexIndicator";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent Force Index indicator series.
 * Default required members: Close, Volume
*
* The `ForceIndexIndicator` represents a IgxDataChartComponent Force Index indicator series.
*
* ```html
* <igx-data-chart
*     [dataSource]="data" >
*     <igx-category-x-axis #xAxis
*         label="label">
*     </igx-category-x-axis>
*     <igx-numeric-y-axis #yAxis>
*     </igx-numeric-y-axis>
*     <igx-force-index-indicator
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         openMemberPath="open"
*         highMemberPath="high"
*         lowMemberPath="low"
*         closeMemberPath="close">
*     </igx-force-index-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxForceIndexIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);;
* ```
*/
export declare class IgxForceIndexIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    protected createImplementation(): ForceIndexIndicator;
    /**
                                 * @hidden
                                 */
    get i(): ForceIndexIndicator;
    constructor();
    /**
     * Gets default display type for the current Financial Indicator
    */
    get defaultDisplayType(): IndicatorDisplayType;
    static ngAcceptInputType_defaultDisplayType: IndicatorDisplayType | string;
    /**
     * Gets or sets the moving average period for the current AverageTrueRangeSeries object.
     * The typical, and initial, value for ForceIndiex periods is 0.
    *
    * You can use the `period` property to get the moving average period of the current FullStochasticOscillatorIndicator object
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data" >
    *     <igx-category-x-axis #xAxis
    *         label="label">
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-force-index-indicator
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         openMemberPath="open"
    *         highMemberPath="high"
    *         lowMemberPath="low"
    *         closeMemberPath="close"
    * 		period=30>
    *     </igx-force-index-indicator>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.period = 30;
    * ```
    */
    get period(): number;
    set period(v: number);
    static ngAcceptInputType_period: number | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxForceIndexIndicatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxForceIndexIndicatorComponent, "igx-force-index-indicator", never, { "period": "period"; }, {}, never, never>;
}
