import { IgPoint } from "igniteui-angular-core";
import { IgxCategoryAxisBaseComponent } from "./igx-category-axis-base-component";
import { IgxNumericYAxisComponent } from "./igx-numeric-y-axis-component";
import { IgxRangeCategorySeriesComponent } from "./igx-range-category-series-component";
import { HorizontalRangeCategorySeries } from "./HorizontalRangeCategorySeries";
import * as i0 from "@angular/core";
/**
 * Base class for ranged category series with a category X-axis and a numeric Y-axis.
*
* Instantiate HorizontalAnchoredCategorySeries
*
* ```html
*  <igx-data-chart
*       [dataSource]="data"  >
* 	 <igx-column-series
*         #series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         valueMemberPath="value"
*           >
*       </igx-column-series>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxColumnSeriesComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.valueMemberPath="value";
* this.chart.series.add(series);
* ```
*/
export declare abstract class IgxHorizontalRangeCategorySeriesComponent extends IgxRangeCategorySeriesComponent {
    /**
                                 * @hidden
                                 */
    get i(): HorizontalRangeCategorySeries;
    constructor();
    /**
     * Gets or sets the effective x-axis for the current CategorySeries object.
    *
    * Instantiate xAxis
    *
    * <!-- Angular -->
    *
    * ```html
    *  <igx-data-chart
    *       [dataSource]="data"  >
    * 	  <igx-category-x-axis
    *         label="label"
    *         #xAxis
    *         >
    *       </igx-category-x-axis>
    * 	 <igx-column-series
    *     ...
    *         [xAxis]="xAxis"
    *     ...
    *           >
    *       </igx-column-series>
    * </igx-data-chart>
    * ```
    */
    get xAxis(): IgxCategoryAxisBaseComponent;
    set xAxis(v: IgxCategoryAxisBaseComponent);
    /**
     * Gets or sets the effective y-axis for the current CategorySeries object.
    *
    * Instantiate yAxis
    *
    * <!-- Angular -->
    *
    * ```js
    *  <igx-data-chart
    *       [dataSource]="data"  >
    * 	  <igx-numeric-y-axis
    *         minimumValue="0"
    *         #yAxis>
    *       </igx-numeric-y-axis>
    * 	 <igx-column-series
    *     ...
    *         [yAxis]="yAxis"
    *     ...
    *           >
    *       </igx-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * let series = new IgxColumnSeriesComponent();
    * series.xAxis = this.xAxis;
    * series.yAxis = this.yAxis;
    * series.valueMemberPath="value";
    * this.chart.series.add(series);
    * ```
    */
    get yAxis(): IgxNumericYAxisComponent;
    set yAxis(v: IgxNumericYAxisComponent);
    /**
     * Checks if this series is a range series
    *
    * You can use the `IsRange` to get the current series is a range type series.
    *
    * <!-- Angular JS -->
    *
    * ```ts
    *   var r = this.series.isRange;
    * ```
    */
    get isRange(): boolean;
    static ngAcceptInputType_isRange: boolean | string;
    /**
     * Gets or sets the label displayed before series' Low value in the Data Legend.
    */
    get lowMemberAsLegendLabel(): string;
    set lowMemberAsLegendLabel(v: string);
    /**
     * Gets or sets the label displayed before series' High value in the Data Legend.
    */
    get highMemberAsLegendLabel(): string;
    set highMemberAsLegendLabel(v: string);
    /**
     * Gets or sets the unit displayed after series' Low value in the Data Legend.
    */
    get lowMemberAsLegendUnit(): string;
    set lowMemberAsLegendUnit(v: string);
    /**
     * Gets or sets the unit displayed after series' High value in the Data Legend.
    */
    get highMemberAsLegendUnit(): string;
    set highMemberAsLegendUnit(v: string);
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    *
    * You can use the `GetOffsetValue` to get the offset value for this series if grouped on a category axis.
    *
    * <!-- Angular JS -->
    *
    *       var g = series.getOffsetValue();
    *
    * <!-- Ignite JS -->
    *
    *      N/A
    */
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    *
    * You can use the `GetCategoryWidth` to get the width of the category grouping a series is in.
    *
    * <!-- Angular JS -->
    *
    *      var x = this.financialSeries.CanUseAsXAxis(this.xAxis);
    *
    * <!-- Ignite JS -->
    *
    *      N/A
    */
    getCategoryWidth(): number;
    getNextOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getPreviousOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesLowValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesLowValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    *
    * You can use the `CanUseAsYAxis` method to determine if object can be used as YAxis
    */
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    *
    * You can use the `CanUseAsXAxis` method to determine if object can be used as XAxis
    *
    * <!-- Angular JS -->
    *
    *      var x = this.financialSeries.CanUseAsXAxis(this.xAxis);
    */
    canUseAsXAxis(axis: any): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxHorizontalRangeCategorySeriesComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxHorizontalRangeCategorySeriesComponent, "ng-component", never, { "xAxis": "xAxis"; "yAxis": "yAxis"; "lowMemberAsLegendLabel": "lowMemberAsLegendLabel"; "highMemberAsLegendLabel": "highMemberAsLegendLabel"; "lowMemberAsLegendUnit": "lowMemberAsLegendUnit"; "highMemberAsLegendUnit": "highMemberAsLegendUnit"; }, {}, never, never>;
}
