import { UnknownValuePlotting } from "igniteui-angular-core";
import { IgxHorizontalAnchoredCategorySeriesComponent } from "./igx-horizontal-anchored-category-series-component";
import { LineSeries } from "./LineSeries";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent line series.
 * Displays trend over time or ordered categories.
 * Useful when there are many data points and the order is important.
*
* `LineSeries` belongs to a group of `CategorySeries` and it is rendered using a collection of points connected by straight line segments.
*
* ```html
*  <igx-data-chart
*     [dataSource]="data">
*     <igx-category-x-axis
*         label="label"
*         #xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
*         #yAxis>
*     </igx-numeric-y-axis>
*     <igx-line-series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         valueMemberPath="value">
*     </igx-line-series>
* </igx-data-chart>
* ```
*
* ```ts
* let series: IgxLineSeriesComponent = new IgxLineSeriesComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.valueMemberPath = "value";
* this.chart.series.add(series);
* ```
*/
export declare class IgxLineSeriesComponent extends IgxHorizontalAnchoredCategorySeriesComponent {
    protected createImplementation(): LineSeries;
    /**
                                 * @hidden
                                 */
    get i(): LineSeries;
    constructor();
    /**
     * Gets whether the current series shows only line shapes.
    */
    get isLineOnly(): boolean;
    static ngAcceptInputType_isLineOnly: boolean | string;
    /**
     * Gets whether the current series shows an area or line shape.
    *
    * Gets whether the `Series` shows an area or a line shape.
    *
    * ```ts
    * let isAreaOrLine: boolean = series.isAreaOrLine;
    * ```
    */
    get isAreaOrLine(): boolean;
    static ngAcceptInputType_isAreaOrLine: boolean | string;
    /**
     * Determines how unknown values will be plotted on the chart.
     * Null and Double.NaN are two examples of unknown values.
    *
    * Determines how unknown values will be plotted for the `Series`. This can be set to `LinearInterpolate` to create a continous shape or `DontPlot` to create breaks in the series.
    *
    * Null and Double.NaN are two examples of unknown values.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         unknownValuePlotting="LinearInterpolate">
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * series.unknownValuePlotting = UnknownValuePlotting.LinearInterpolate;
    * ```
    */
    get unknownValuePlotting(): UnknownValuePlotting;
    set unknownValuePlotting(v: UnknownValuePlotting);
    static ngAcceptInputType_unknownValuePlotting: UnknownValuePlotting | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxLineSeriesComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxLineSeriesComponent, "igx-line-series", never, { "unknownValuePlotting": "unknownValuePlotting"; }, {}, never, never>;
}
