import { IndicatorDisplayType } from "./IndicatorDisplayType";
import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { MoneyFlowIndexIndicator } from "./MoneyFlowIndexIndicator";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent Money Flow Index indicator series.
 * Default required members: Close, Low, High, Volume
*
* Represents a Ignite UIDataChart Money Flow Index indicator series.
*
* Example:
*
* ```html
* <igx-data-chart
*     [dataSource]="data">
* 	<igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
* 	<igx-money-flow-index-indicator
*         #series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
* 		openMemberPath="open"
*         highMemberPath="high"
* 		lowMemberPath="low"
* 		closeMemberPath="close"
* 		volumeMemberPath="volume">
*     </igx-money-flow-index-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxMoneyFlowIndexIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath="open"
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath="close"
* series.volumeMemberPath= "volume";
* this.chart.series.add(series);
* ```
*/
export declare class IgxMoneyFlowIndexIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    protected createImplementation(): MoneyFlowIndexIndicator;
    /**
                                 * @hidden
                                 */
    get i(): MoneyFlowIndexIndicator;
    constructor();
    /**
     * Gets default display type for the current Financial Indicator
    */
    get defaultDisplayType(): IndicatorDisplayType;
    static ngAcceptInputType_defaultDisplayType: IndicatorDisplayType | string;
    /**
     * Gets or sets the moving average period for the current MoneyFlowIndexIndicator object.
     * The typical, and initial, value for MoneyFlowIndexIndicator periods is 14.
    *
    * Gets or sets the moving average period for the current MoneyFlowIndexIndicator object.
    *
    * Example:
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    * 	<igx-category-x-axis
    * 		label="label"
    * 		#xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    * 		#yAxis>
    *     </igx-numeric-y-axis>
    * 	<igx-money-flow-index-indicator
    *         #series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    * 		openMemberPath="open"
    *         highMemberPath="high"
    * 		lowMemberPath="low"
    * 		closeMemberPath="close"
    * 		volumeMemberPath="volume"
    * 		period="14">
    *     </igx-money-flow-index-indicator>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.period = 14;
    * ```
    */
    get period(): number;
    set period(v: number);
    static ngAcceptInputType_period: number | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxMoneyFlowIndexIndicatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxMoneyFlowIndexIndicatorComponent, "igx-money-flow-index-indicator", never, { "period": "period"; }, {}, never, never>;
}
