import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { RangeCategorySeries } from "./RangeCategorySeries";
import * as i0 from "@angular/core";
/**
 * Represents the base class for all IgxDataChartComponent ranged category/value series.
*
* The `RangeCategorySeries` represents the base class for all IgxDataChartComponent ranged category/value series.
*
* ```html
* <igx-data-chart  #chart
*     [dataSource]="data">
*     <igx-category-x-axis
*     label="label"
*     #xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
*     minimumValue="0"
*     #yAxis>
*     </igx-numeric-y-axis>
*     <igx-range-column-series
*     [xAxis]="xAxis"
*     [yAxis]="yAxis"
*     highMemberPath="high"
*     lowMemberPath="low">
* </igx-range-column-series>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxRangeColumnSeriesComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* this.chart.series.add(series);
* ```
*/
export declare abstract class IgxRangeCategorySeriesComponent extends IgxCategorySeriesComponent {
    /**
                                 * @hidden
                                 */
    get i(): RangeCategorySeries;
    constructor();
    /**
     * Gets or sets the value mapping property for the current series object.
    *
    * The `LowMemberPath` is used for low mapping property of the current series object.
    *
    * ```html
    * <igx-data-chart  #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *     label="label"
    *     #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *     minimumValue="0"
    *     #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-range-column-series
    *     [xAxis]="xAxis"
    *     [yAxis]="yAxis"
    *     highMemberPath="high"
    *     lowMemberPath="low">
    * </igx-range-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * let series = new IgxRangeColumnSeriesComponent();
    * series.xAxis = this.xAxis;
    * series.yAxis = this.yAxis;
    * series.highMemberPath = "high";
    * series.lowMemberPath = "low";
    * this.chart.series.add(series);
    * ```
    */
    get lowMemberPath(): string;
    set lowMemberPath(v: string);
    /**
     * Gets or sets the value mapping property for the current series object.
    *
    * Use `HighMemberPath` propert for high mapping of the current series object.
    *
    * ```html
    * <igx-data-chart  #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *     label="label"
    *     #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *     minimumValue="0"
    *     #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-range-column-series
    *     [xAxis]="xAxis"
    *     [yAxis]="yAxis"
    *     highMemberPath="high"
    *     lowMemberPath="low">
    * </igx-range-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * series.highMemberPath = "high";
    * ```
    */
    get highMemberPath(): string;
    set highMemberPath(v: string);
    getItemValue(item: any, memberPathName: string): any;
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    *
    * `ScrollIntoView` method Scrolls the series to display the item for the specified data item.
    */
    scrollIntoView(item: any): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxRangeCategorySeriesComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxRangeCategorySeriesComponent, "ng-component", never, { "lowMemberPath": "lowMemberPath"; "highMemberPath": "highMemberPath"; }, {}, never, never>;
}
