import { EventEmitter, TemplateRef, OnInit } from '@angular/core';
import { Visibility } from "igniteui-angular-core";
import { IgRect } from "igniteui-angular-core";
import { IgPoint } from "igniteui-angular-core";
import { IgDataTemplate } from "igniteui-angular-core";
import { TransitionInSpeedType } from './TransitionInSpeedType';
import { SeriesHitTestMode } from './SeriesHitTestMode';
import { IgxAxisComponent } from './igx-axis-component';
import { Series } from './Series';
import { IgxRenderRequestedEventArgs } from './igx-render-requested-event-args';
import { SeriesVisibleRangeMode } from './SeriesVisibleRangeMode';
import { SeriesHighlightingMode } from './SeriesHighlightingMode';
import { SeriesOutlineMode } from './SeriesOutlineMode';
import { LegendItemBadgeMode } from "igniteui-angular-core";
import { LegendItemBadgeShape } from "igniteui-angular-core";
import { PenLineJoin } from "igniteui-angular-core";
import { PenLineCap } from "igniteui-angular-core";
import { ValueLayerValueMode } from './ValueLayerValueMode';
import * as i0 from "@angular/core";
export declare const IgxSeriesComponent_PROVIDERS: any[];
/**
 * Represents the base class for all IgxDataChartComponent series.
*/
export declare class IgxSeriesComponent implements OnInit {
    protected _implementation: any;
    get i(): Series;
    private onImplementationCreated;
    protected createImplementation(): Series;
    constructor();
    get seriesInternal(): any;
    ngOnInit(): void;
    set name(value: string);
    get name(): string;
    /**
     * Gets or sets the legend used for the current series.
    */
    get legend(): any;
    set legend(v: any);
    private _chartLevelData;
    provideData(data: any[]): void;
    protected onUpdateDataSource(dataSource: any): any;
    private updateDataSource;
    private _dataSource;
    set dataSource(value: any);
    get dataSource(): any;
    bindAxes(axes: IgxAxisComponent[]): void;
    private _tooltipTemplate;
    private _tooltipContent;
    set tooltipTemplate(value: TemplateRef<any>);
    get tooltipTemplate(): TemplateRef<any>;
    private _tooltipContainerTemplate;
    set tooltipContainerTemplate(value: TemplateRef<any>);
    get tooltipContainerTemplate(): TemplateRef<any>;
    private _ensureTooltipCreated;
    private _ensureTooltipDestroyed;
    private _renderer;
    private _provideRenderer;
    static _createFromInternal(internal: any): IgxSeriesComponent;
    /**
 * Gets unique key used to identify the series in data legend
*/
    get dataLegendKey(): string;
    /**
     * Gets whether the series is an annotation layer.
    *
    * ```ts
    * let isAnnotationLayer: boolean = this.series.isAnnotationLayer;
    * ```
    */
    get isAnnotationLayer(): boolean;
    static ngAcceptInputType_isAnnotationLayer: boolean | string;
    /**
     * Gets whether the series is an crosshair annotation layer.
    */
    get isAnnotationCrosshairLayer(): boolean;
    static ngAcceptInputType_isAnnotationCrosshairLayer: boolean | string;
    /**
     * Gets whether the series is an callout annotation layer.
    */
    get isAnnotationCalloutLayer(): boolean;
    static ngAcceptInputType_isAnnotationCalloutLayer: boolean | string;
    /**
     * Gets whether the series is an annotation layer displayed only when hovering over the chart.
     * Crosshair Layer, Category Highlight Layer, Category Tooltip Layer, Item Tooltip Layer
    */
    get isAnnotationHoverLayer(): boolean;
    static ngAcceptInputType_isAnnotationHoverLayer: boolean | string;
    /**
     * Gets whether the series is final value annotation layer.
    */
    get isAnnotationFinalValue(): boolean;
    static ngAcceptInputType_isAnnotationFinalValue: boolean | string;
    /**
     * Gets whether the series is a value annotation layer.
    */
    get isAnnotationValueLayer(): boolean;
    static ngAcceptInputType_isAnnotationValueLayer: boolean | string;
    /**
     * Gets whether the current series is oriented vertically.
    *
    * ```ts
    * let isVertical: boolean = this.series.isVertical;
    * ```
    */
    get isVertical(): boolean;
    static ngAcceptInputType_isVertical: boolean | string;
    /**
     * Gets whether the current series is a stack fragment.
    *
    * ```ts
    * let isFragment: boolean = this.series.isFragment;
    * ```
    */
    get isFragment(): boolean;
    static ngAcceptInputType_isFragment: boolean | string;
    /**
     * Gets whether the current series shows an area or line shape.
    *
    * ```ts
    * let isAreaorLine: boolean = this.series.isAreaorLine;
    * ```
    */
    get isAreaOrLine(): boolean;
    static ngAcceptInputType_isAreaOrLine: boolean | string;
    /**
     * Gets whether the current series shows an area shape.
    */
    get isArea(): boolean;
    static ngAcceptInputType_isArea: boolean | string;
    /**
     * Gets whether the current series shows an area shape.
    */
    get hasValueAxis(): boolean;
    static ngAcceptInputType_hasValueAxis: boolean | string;
    /**
     * Gets whether the current series shows an area shape.
    */
    get isValueAxisInverted(): boolean;
    static ngAcceptInputType_isValueAxisInverted: boolean | string;
    /**
     * Gets whether the current series shows only line shapes.
    */
    get isLineOnly(): boolean;
    static ngAcceptInputType_isLineOnly: boolean | string;
    /**
     * Gets whether the current series shows a line contour shape.
    */
    get isLineContour(): boolean;
    static ngAcceptInputType_isLineContour: boolean | string;
    /**
     * Gets whether the current series shows a spline shape.
    */
    get isSpline(): boolean;
    static ngAcceptInputType_isSpline: boolean | string;
    /**
     * Gets whether the current series shows a column shape.
    */
    get isColumn(): boolean;
    static ngAcceptInputType_isColumn: boolean | string;
    /**
     * Gets whether the current series shows a horizontal column shape.
    */
    get isBar(): boolean;
    static ngAcceptInputType_isBar: boolean | string;
    /**
     * Gets whether the current series shows a waterfall column shape.
    */
    get isWaterfall(): boolean;
    static ngAcceptInputType_isWaterfall: boolean | string;
    /**
     * Gets whether the current series shows a polyline shape.
    */
    get isPolyline(): boolean;
    static ngAcceptInputType_isPolyline: boolean | string;
    /**
     * Gets whether the current series shows a polygon shape.
    */
    get isPolygon(): boolean;
    static ngAcceptInputType_isPolygon: boolean | string;
    /**
     * Gets whether the current series shows pixels.
    */
    get isPixel(): boolean;
    static ngAcceptInputType_isPixel: boolean | string;
    /**
     * Gets whether the current series shows a pie shape.
    */
    get isPie(): boolean;
    static ngAcceptInputType_isPie: boolean | string;
    /**
     * Gets whether the current series shows a tile imagery.
    */
    get isTile(): boolean;
    static ngAcceptInputType_isTile: boolean | string;
    /**
     * Gets whether the current series shows step shapes.
    */
    get isStep(): boolean;
    static ngAcceptInputType_isStep: boolean | string;
    /**
     * Gets whether the current series shows interactive shape controls.
    */
    get isShapeControl(): boolean;
    static ngAcceptInputType_isShapeControl: boolean | string;
    /**
     * Gets whether the current series is a polar type series.
    *
    * ```ts
    * let isPolar: boolean = this.series.isPolar;
    * ```
    */
    get isPolar(): boolean;
    static ngAcceptInputType_isPolar: boolean | string;
    /**
     * Gets whether the current series is a scatter type series.
    *
    * ```ts
    * let isScatter: boolean = this.series.isScatter;
    * ```
    */
    get isScatter(): boolean;
    static ngAcceptInputType_isScatter: boolean | string;
    /**
     * Gets whether the current series is a radial type series.
    *
    * ```ts
    * let isRadial: boolean = this.series.isRadial;
    * ```
    */
    get isRadial(): boolean;
    static ngAcceptInputType_isRadial: boolean | string;
    /**
     * Gets whether the current series is a stacked type series.
    *
    * ```ts
    * let isStacked: boolean = this.series.isStacked;
    * ```
    */
    get isStacked(): boolean;
    static ngAcceptInputType_isStacked: boolean | string;
    /**
     * Gets whether the current series is a financial type series.
    *
    * ```ts
    * let isFinancial: boolean = this.series.isFinancial;
    * ```
    */
    get isFinancial(): boolean;
    static ngAcceptInputType_isFinancial: boolean | string;
    /**
     * Gets whether the current series is a range type series.
    *
    * ```ts
    * let isRange: boolean = this.series.isRange;
    * ```
    */
    get isRange(): boolean;
    static ngAcceptInputType_isRange: boolean | string;
    /**
     * Gets whether the current series is a category type series.
    *
    * ```ts
    * let isCategory: boolean = this.series.isCategory;
    * ```
    */
    get isCategory(): boolean;
    static ngAcceptInputType_isCategory: boolean | string;
    /**
     * Gets whether the current series is a geographic series.
    *
    * ```ts
    * let isGeographic: boolean = this.series.isGeographic;
    * ```
    */
    get isGeographic(): boolean;
    static ngAcceptInputType_isGeographic: boolean | string;
    /**
     * Gets whether the current series is a shape type series.
    */
    get isShape(): boolean;
    static ngAcceptInputType_isShape: boolean | string;
    /**
     * Gets whether the series is a value overlay.
    */
    get isValueOverlay(): boolean;
    static ngAcceptInputType_isValueOverlay: boolean | string;
    /**
     * Gets whether the series has only marker as visuals
    */
    get hasOnlyMarkers(): boolean;
    static ngAcceptInputType_hasOnlyMarkers: boolean | string;
    /**
     * Gets whether the series has financial OHLC/candlestick visuals
    */
    get isFinancialSeries(): boolean;
    static ngAcceptInputType_isFinancialSeries: boolean | string;
    /**
     * Gets whether the series is financial overlay
    */
    get isFinancialOverlay(): boolean;
    static ngAcceptInputType_isFinancialOverlay: boolean | string;
    /**
     * Gets whether the series is financial indicator
    */
    get isFinancialIndicator(): boolean;
    static ngAcceptInputType_isFinancialIndicator: boolean | string;
    /**
     * Gets whether the series is financial waterfall
    */
    get isFinancialWaterfall(): boolean;
    static ngAcceptInputType_isFinancialWaterfall: boolean | string;
    /**
     * Gets whether the default crosshair behavior should be disabled if this series is present.
    *
    * `IsDefaultCrosshairBehaviorDisabled` defaults to true for annotation layers. When not using annotaion layers, you can show crosshairs by setting the chart's `CrosshairVisibility` to true.
    *
    * ```ts
    * let isDefaultCrosshairBehaviorDisabled: boolean = this.series.isDefaultCrosshairBehaviorDisabled;
    * ```
    */
    get isDefaultCrosshairBehaviorDisabled(): boolean;
    static ngAcceptInputType_isDefaultCrosshairBehaviorDisabled: boolean | string;
    /**
     * Gets whether the default tooltip behavior should be disabled if this series is present.
    *
    * ```ts
    *  let isDefaultTooltipBehaviorDisabled: boolean = this.series.isDefaultTooltipBehaviorDisabled;
    * ```
    */
    get isDefaultTooltipBehaviorDisabled(): boolean;
    static ngAcceptInputType_isDefaultTooltipBehaviorDisabled: boolean | string;
    /**
     * Returns whether the current series supports visual markers.
    *
    * ```ts
    * let hasMarkers: boolean = this.series.hasMarkers;
    * ```
    */
    get hasMarkers(): boolean;
    static ngAcceptInputType_hasMarkers: boolean | string;
    /**
     * Gets if the series uses an index, which can be used to auto-assign it a color.
    *
    * ```ts
    * let isIndexed: boolean = this.series.isIndexed;
    * ```
    */
    get isIndexed(): boolean;
    static ngAcceptInputType_isIndexed: boolean | string;
    /**
     * Gets if the series should appear in any legends.
    *
    * ```ts
    * let isUsableInLegend: boolean = this.series.isUsableInLegend;
    * ```
    */
    get isUsableInLegend(): boolean;
    static ngAcceptInputType_isUsableInLegend: boolean | string;
    /**
     * Gets or sets the legend item visibility for the current series object.
    *
    * The `LegendItemVisibilty` can be used to exclude only certain `Series` from the `Legend`.
    */
    get legendItemVisibility(): Visibility;
    set legendItemVisibility(v: Visibility);
    static ngAcceptInputType_legendItemVisibility: Visibility | string;
    /**
     * Gets or sets the LegendItemBadgeTemplate property.
     * The legend item badge is created according to the LegendItemBadgeTemplate on-demand by
     * the series object itself.
    */
    get legendItemBadgeTemplate(): IgDataTemplate;
    set legendItemBadgeTemplate(v: IgDataTemplate);
    /**
     * Gets the actual legend item badge template used by the series.
    */
    get actualLegendItemBadgeTemplate(): IgDataTemplate;
    set actualLegendItemBadgeTemplate(v: IgDataTemplate);
    /**
     * Gets the effective legend badge outline for the current series.
    */
    get actualLegendItemBadgeOutline(): string;
    set actualLegendItemBadgeOutline(v: string);
    /**
     * Gets the effective legend badge fill for the current series.
    */
    get actualLegendItemBadgeBrush(): string;
    set actualLegendItemBadgeBrush(v: string);
    /**
     * Gets or sets the type of legend badge representing the current series in a legend.
     * This property will be ignored when the LegendItemTemplate/LegendItemBadgeTemplate property is set on the series
    */
    get legendItemBadgeShape(): LegendItemBadgeShape;
    set legendItemBadgeShape(v: LegendItemBadgeShape);
    static ngAcceptInputType_legendItemBadgeShape: LegendItemBadgeShape | string;
    /**
     * Gets or sets the mode of legend badge representing the current series in a legend.
     * This property will be ignored when the LegendItemTemplate/LegendItemBadgeTemplate property is set on the series
    */
    get legendItemBadgeMode(): LegendItemBadgeMode;
    set legendItemBadgeMode(v: LegendItemBadgeMode);
    static ngAcceptInputType_legendItemBadgeMode: LegendItemBadgeMode | string;
    /**
     * Gets or sets the LegendItemTemplate property.
     * The legend item control content is created according to the LegendItemTemplate on-demand by
     * the series object itself.
    */
    get legendItemTemplate(): IgDataTemplate;
    set legendItemTemplate(v: IgDataTemplate);
    /**
     * Gets or sets the DiscreteLegendItemTemplate property.
     * The legend item control content is created according to the DiscreteLegendItemTemplate on-demand by
     * the series object itself.
    */
    get discreteLegendItemTemplate(): IgDataTemplate;
    set discreteLegendItemTemplate(v: IgDataTemplate);
    /**
     * Gets or sets the easing function used to morph the current series.
    *
    * The `TransitioninDuration` and `TransitionEasingFunction` can be used to play animation when data is added or removed from a `Series`. To play an initial animation see `TransitionInDuration`.
    *
    * ```ts
    * this.series.transitionEasingFunction =  EasingFunctions.cubicEase;
    * ```
    */
    get transitionEasingFunction(): (time: number) => number;
    set transitionEasingFunction(v: (time: number) => number);
    /**
     * Gets or sets the EasingFunction used to morph the current series during the initial transition.
    *
    * The `TransitionInEasingFunction` can be used with `IsTransitionInEnabled` to cofigure the animation when a new datasource is loaded.
    *
    * ```ts
    * this.series.transitionInEasingFunction =  EasingFunctions.cubicEase;
    * ```
    */
    get transitionInEasingFunction(): (time: number) => number;
    set transitionInEasingFunction(v: (time: number) => number);
    /**
     * Gets or sets the duration of the current series's morph.
    *
    * The `TransitionDuration` can be used to play animation when data is added or removed from a `Series`. To play an initial animation see `TransitionInDuration`.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data"
    *     animateSeriesWhenAxisRangeChanges=true>
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         transitionInMode="accordionFromBottom"
    *         isTransitionInEnabled=true
    *         transitionInSpeedType="indexScaled"
    *         transitionDuration=500
    *         transitionInDuration=500>
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.transitionDuration = 500;
    * ```
    */
    get transitionDuration(): number;
    set transitionDuration(v: number);
    static ngAcceptInputType_transitionDuration: number | string;
    get actualResolution(): number;
    set actualResolution(v: number);
    static ngAcceptInputType_actualResolution: number | string;
    /**
     * Gets or sets the current series object's rendering resolution.
    *
    * Setting the `Resolution` on a Series to a higher value can help with performance, but it will lower the graphical fidelity of the line. As such, it can be increased up until the fidelity is unacceptable.
    *
    * ```html
    *  <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         resolution=1.5>
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.resolution = 1.5;
    * ```
    */
    get resolution(): number;
    set resolution(v: number);
    static ngAcceptInputType_resolution: number | string;
    /**
     * Gets or sets the top margin to use when getting a visible axis range for the series.
    */
    get visibleRangeMarginTop(): number;
    set visibleRangeMarginTop(v: number);
    static ngAcceptInputType_visibleRangeMarginTop: number | string;
    /**
     * Gets or sets the bottom margin to use when getting a visible axis range for the series.
    */
    get visibleRangeMarginBottom(): number;
    set visibleRangeMarginBottom(v: number);
    static ngAcceptInputType_visibleRangeMarginBottom: number | string;
    /**
     * Gets or sets the left margin to use when getting a visible axis range for the series.
    */
    get visibleRangeMarginLeft(): number;
    set visibleRangeMarginLeft(v: number);
    static ngAcceptInputType_visibleRangeMarginLeft: number | string;
    /**
     * Gets or sets the right margin to use when getting a visible axis range for the series.
    */
    get visibleRangeMarginRight(): number;
    set visibleRangeMarginRight(v: number);
    static ngAcceptInputType_visibleRangeMarginRight: number | string;
    /**
     * Gets or sets the Title property.
     * The legend item control is created according to the Title on-demand by
     * the series object itself.
    *
    * The `Series` `Title` may be used in tooltips and legends.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         showDefaultTooltip="true"
    *         title="InStock Items">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.title = "InStock Items";
    * ```
    */
    get title(): any;
    set title(v: any);
    /**
     * Gets or sets the brush to use for the series.
    *
    * The `Brush` along with the `Outline` and `Negative Brush` can be used to affect the visuals of the `Series`.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-area-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         brush="red">
    *     </igx-area-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.brush = "red";
    * ```
    */
    get brush(): string;
    set brush(v: string);
    /**
     * Gets the effective brush for the current series object.
    *
    * ```ts
    * let actualBrush: string = series.actualBrush;
    * ```
    */
    get actualBrush(): string;
    set actualBrush(v: string);
    /**
     * Gets or sets the brush to use for the outline of the series.
     * Some series types, such as LineSeries, do not display outlines.  Therefore, this property does not affect some charts.
    *
    * The `Outline` along with the `Brush` and `NegativeBrush` can be used to affect the visuals of the `Series`.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-area-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         outline="red">
    *     </igx-area-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.brush = "red";
    * ```
    */
    get outline(): string;
    set outline(v: string);
    /**
     * Gets the effective outline for the current series object.
    *
    * ```ts
    * let actualOutline: string = series.ActualOutline;
    * ```
    */
    get actualOutline(): string;
    set actualOutline(v: string);
    /**
     * Gets or sets the brush that specifies current series object's line join style.
    */
    get lineJoin(): PenLineJoin;
    set lineJoin(v: PenLineJoin);
    static ngAcceptInputType_lineJoin: PenLineJoin | string;
    /**
     * Gets or sets the width of the current series object's line thickness.
    *
    * Depending on the `Series` type, this can be the main brush used, or just the outline. For example, when using a `LineSeries` it will affect the thickness of the lines drawn, whereas when using a `ColumnSeries` it will affect the outer border thickness of the columns.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         thickness=5>
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.thickness=5;
    * ```
    */
    get thickness(): number;
    set thickness(v: number);
    static ngAcceptInputType_thickness: number | string;
    /**
     * Gets the effective Thickness for the current series object.
    */
    get actualThickness(): number;
    set actualThickness(v: number);
    static ngAcceptInputType_actualThickness: number | string;
    /**
     * Gets or sets a collection of Double values that indicate the pattern of dashes and gaps that
     * is used to outline the current series object.
    */
    get dashArray(): number[];
    set dashArray(v: number[]);
    static ngAcceptInputType_dashArray: number[] | string;
    /**
     * Gets actual highlighting mode
    */
    get actualHighlightingMode(): SeriesHighlightingMode;
    set actualHighlightingMode(v: SeriesHighlightingMode);
    static ngAcceptInputType_actualHighlightingMode: SeriesHighlightingMode | string;
    /**
     * Gets actual highlighting fade opacity
    */
    get actualHighlightingFadeOpacity(): number;
    set actualHighlightingFadeOpacity(v: number);
    static ngAcceptInputType_actualHighlightingFadeOpacity: number | string;
    /**
     * Gets or sets the target opacity to fade to for fade style highlighting.
    */
    get highlightingFadeOpacity(): number;
    set highlightingFadeOpacity(v: number);
    static ngAcceptInputType_highlightingFadeOpacity: number | string;
    /**
     * Gets or sets whether the ActualLegend is FinancialLegend or normal Legend.
    */
    get isActualLegendFinancial(): boolean;
    set isActualLegendFinancial(v: boolean);
    static ngAcceptInputType_isActualLegendFinancial: boolean | string;
    /**
     * Gets or sets whether the component level highlight mode is ignored.
    */
    get isComponentHighlightingModeIgnored(): boolean;
    set isComponentHighlightingModeIgnored(v: boolean);
    static ngAcceptInputType_isComponentHighlightingModeIgnored: boolean | string;
    /**
     * Gets or sets whether highlighting should be enabled for this series, if this type of series supports highlighting.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isHighlightEnabled="true">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.isHighlightingEnabled = true;
    * ```
    */
    get isHighlightingEnabled(): boolean;
    set isHighlightingEnabled(v: boolean);
    static ngAcceptInputType_isHighlightingEnabled: boolean | string;
    /**
     * Gets or sets whether this series should suppress it's auto callouts
    */
    get shouldHideAutoCallouts(): boolean;
    set shouldHideAutoCallouts(v: boolean);
    static ngAcceptInputType_shouldHideAutoCallouts: boolean | string;
    /**
     * Gets or sets whether drop shadow should be enabled for this series.
    *
    * `IsDropShadowEnabled` is used to decide whether drop shadow should be enabled for this series.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isDropShadowEnabled=true>
    *     </igx-line-series>
    *     </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.isDropShadowEnabled = true;
    * ```
    */
    get isDropShadowEnabled(): boolean;
    set isDropShadowEnabled(v: boolean);
    static ngAcceptInputType_isDropShadowEnabled: boolean | string;
    /**
     * Gets or sets the shadow blur.
     * This property is ignored when
     * Series.UseSingleShadow is set to true.
    *
    * `ShadowBlur` can be set in conjection with `IsDropShadowEnabled` to further define the drop shadow effect.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isDropShadowEnabled="true"
    *         shadowBlur="7"
    *         shadowColor="blue">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.shadowBlur = 7;
    * ```
    */
    get shadowBlur(): number;
    set shadowBlur(v: number);
    static ngAcceptInputType_shadowBlur: number | string;
    /**
     * Gets or sets the drop shadow color.
    *
    * `ShadowColor` can be set in conjection with `IsDropShadowEnabled` to further define the drop shadow effect.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isDropShadowEnabled="true"
    *         shadowBlur="7"
    *         shadowColor="blue">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.shadowColor = "blue";
    * ```
    */
    get shadowColor(): string;
    set shadowColor(v: string);
    /**
     * Gets or sets whether drop shadow is applied to the whole series visual or to each of the individual shapes forming the series.
     * When this property is set to true, no
     * Series.ShadowBlur is applied.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isDropShadowEnabled=true
    *         markerType="circle"
    *         useSingleShadow=true>
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.useSingleShadow = true;
    * ```
    */
    get useSingleShadow(): boolean;
    set useSingleShadow(v: boolean);
    static ngAcceptInputType_useSingleShadow: boolean | string;
    /**
     * Gets or sets the drop shadow x-offset.
    *
    * `ShadowOffsetX` can be set in conjection with `IsDropShadowEnabled` to further define the drop shadow effect.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isDropShadowEnabled="true"
    *         shadowOffsetX="10"
    *         shadowOffsetY="10">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.shadowOffsetX = 10;
    * ```
    */
    get shadowOffsetX(): number;
    set shadowOffsetX(v: number);
    static ngAcceptInputType_shadowOffsetX: number | string;
    /**
     * Gets or sets the drop shadow y-offset.
    *
    * `ShadowOffsetY` can be set in conjection with `IsDropShadowEnabled` to further define the drop shadow effect.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isDropShadowEnabled="true"
    *         shadowOffsetX="10"
    *         shadowOffsetY="10">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.shadowOffsetY = 10;
    * ```
    */
    get shadowOffsetY(): number;
    set shadowOffsetY(v: number);
    static ngAcceptInputType_shadowOffsetY: number | string;
    /**
     * Gets or sets the opacity applied to the area fill visual.
     * This property only applies to series that have area visual.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-area-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         areaFillOpacity=.5>
    *     </igx-area-series>
    * </igx-data-chart>
    * ```
    */
    get areaFillOpacity(): number;
    set areaFillOpacity(v: number);
    static ngAcceptInputType_areaFillOpacity: number | string;
    /**
     * Gets the actual opacity applied to the area fill visual.
    *
    * ```ts
    * let actualFillOpacity: number = series.actualAreaFillOpacity;
    * ```
    */
    get actualAreaFillOpacity(): number;
    set actualAreaFillOpacity(v: number);
    static ngAcceptInputType_actualAreaFillOpacity: number | string;
    /**
     * Gets or sets the opacity applied to the fill of the markers.
     * This property only applies to series that have area visual.
    */
    get markerFillOpacity(): number;
    set markerFillOpacity(v: number);
    static ngAcceptInputType_markerFillOpacity: number | string;
    /**
     * Gets the actual opacity applied to the fill of the markers.
    */
    get actualMarkerFillOpacity(): number;
    set actualMarkerFillOpacity(v: number);
    static ngAcceptInputType_actualMarkerFillOpacity: number | string;
    /**
     * Gets if the default tooltip has been selected for display.
    *
    * To use the default tooltip set `ShowDefaultTooltip` to true.
    *
    * ```ts
    * let isDefaultToolTipSelected: boolean = this.series.isDefaultToolTipSelected;
    * ```
    */
    get isDefaultToolTipSelected(): boolean;
    set isDefaultToolTipSelected(v: boolean);
    static ngAcceptInputType_isDefaultToolTipSelected: boolean | string;
    /**
     * Gets or sets whether default tooltip will be shown.
    *
    * The default tooltips display all the information relevant to the particular series item (series title, data values, axis values etc.) and are styled to match the series' style. When using default tooltips, you should also set the series `Title`.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         showDefaultTooltip="true"
    *         title="InStock Items">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.showDefaultTooltip ="true";
    * ```
    */
    get showDefaultTooltip(): boolean;
    set showDefaultTooltip(v: boolean);
    static ngAcceptInputType_showDefaultTooltip: boolean | string;
    /**
     * Gets or sets the visible range mode to use.
    */
    get visibleRangeMode(): SeriesVisibleRangeMode;
    set visibleRangeMode(v: SeriesVisibleRangeMode);
    static ngAcceptInputType_visibleRangeMode: SeriesVisibleRangeMode | string;
    /**
     * Gets or sets the outline mode to use for the series.
    */
    get outlineMode(): SeriesOutlineMode;
    set outlineMode(v: SeriesOutlineMode);
    static ngAcceptInputType_outlineMode: SeriesOutlineMode | string;
    /**
     * Gets or sets the duration of the current series's transition in morph.
    *
    * The `TransitionInDuration` can be used with `IsTransitionInEnabled` to cofigure the animation when a new datasource is loaded.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         transitionInMode="accordionFromBottom"
    *         isTransitionInEnabled=true
    *         transitionInSpeedType="indexScaled"
    *         transitionDuration=500
    *         transitionInDuration=500>
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.transitionDuration = 500;
    * ```
    */
    get transitionInDuration(): number;
    set transitionInDuration(v: number);
    static ngAcceptInputType_transitionInDuration: number | string;
    /**
     * Gets or sets the duration of the current series's transition in morph.
    *
    * The `TransitionInSpeedType` can be used with `IsTransitionInEnabled` to cofigure the animation when a new datasource is loaded.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         transitionInMode="accordionFromBottom"
    *         isTransitionInEnabled=true
    *         transitionInSpeedType="indexScaled"
    *         transitionInDuration=500>
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.transitionInSpeedType = TransitionInSpeedType.IndexScaled;
    * ```
    */
    get transitionInSpeedType(): TransitionInSpeedType;
    set transitionInSpeedType(v: TransitionInSpeedType);
    static ngAcceptInputType_transitionInSpeedType: TransitionInSpeedType | string;
    /**
     * Gets or sets the style of the starting point of any lines or polylines representing this series.
     * Not every series type has a line at which it would be appropriate to display a start cap, so this property does not affect every series type.  LineSeries, for example, is affected by StartCap, but ColumnSeries is not.
    */
    get lineCap(): PenLineCap;
    set lineCap(v: PenLineCap);
    static ngAcceptInputType_lineCap: PenLineCap | string;
    /**
     * Gets or sets the whether the chart reacts to mouse move events.
    */
    get mouseOverEnabled(): boolean;
    set mouseOverEnabled(v: boolean);
    static ngAcceptInputType_mouseOverEnabled: boolean | string;
    /**
     * Gets or sets the coercion methods to use when loading data from data sources.
     * Should be specified before setting any member paths, if being used. Setting it later
     * will not cause data to be reimported into the chart.
    *
    * ```html
    *  <igx-data-chart
    *       [dataSource]="data"
    *      >
    *       <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *       </igx-category-x-axis>
    *       <igx-numeric-y-axis
    *         #yAxis>
    *       </igx-numeric-y-axis>
    *       <igx-line-series
    *       [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       valueMemberPath="value">
    *      </igx-line-series>
    *        <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         [coercionMethods]= cMethods
    *         valueMemberPath="value!ValueCoercion">
    *        </igx-line-series>
    *     </igx-data-chart>
    * ```
    *
    * &lt;-- position: content member-->
    *
    * ```ts
    * cMethods: any = {
    *     ValueCoercion: function(value:number): number {return value+2;}
    *  }
    * ```
    */
    get coercionMethods(): any;
    set coercionMethods(v: any);
    /**
     * Gets or sets whether the series should expect that properties in its items source may be functions that need to be
     * evaluated to yield their value. This defaults to false, as there will be a subtle performance impact to using this feature.
     * This value must be set before assigning an item's source to take effect.
    *
    * `expectFunctions` is used to decide whether the series should expect that its data source members need to be called as functions to get their values.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *     label="label"
    *     #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *     #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *     [xAxis]="xAxis"
    *     [yAxis]="yAxis"
    *     expectFunctions=true
    *     valueMemberPath="MyFunction">
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.expectFunctions=true;
    * ```
    */
    get expectFunctions(): boolean;
    set expectFunctions(v: boolean);
    static ngAcceptInputType_expectFunctions: boolean | string;
    /**
     * Method of hit testing to use when pointing to items in this series.
    *
    * The `HitTestMode` can be set to either:
    *
    * -   `Auto`: automatically decide the appropriate hit test mode for the series.
    * -   `ColorEncoded`: use a color encoded off screen buffer for hit testing. Should always be O(1) time for determining a hit series. This increases frame render time and memory usage, however. Consider using this if hit testing time is degrading performance.
    * -   `Computational`: use a computational based approach to determine whether the series has been hit. This uses loose bounding boxes, in some cases, and can range in time complexity between O(1) and O(log n) to find a hit. This decreases frame render time compared to color encoded
    *
    * ```ts
    * this.series.hitTestMode = SeriesHitTestMode.Computational;
    * ```
    */
    get hitTestMode(): SeriesHitTestMode;
    set hitTestMode(v: SeriesHitTestMode);
    static ngAcceptInputType_hitTestMode: SeriesHitTestMode | string;
    /**
     * Resolved method of hit testing to use when pointing to items in the chart.
    *
    * ```ts
    * let hitTestMode: SeriesHitTestMode = this.series.actualHitTestMode;
    * ```
    */
    get actualHitTestMode(): SeriesHitTestMode;
    set actualHitTestMode(v: SeriesHitTestMode);
    static ngAcceptInputType_actualHitTestMode: SeriesHitTestMode | string;
    /**
     * Overridden by derived series classes to indicate when negative colors are supported or not.
    */
    get isNegativeColorSupported(): boolean;
    static ngAcceptInputType_isNegativeColorSupported: boolean | string;
    /**
     * Overridden by derived series classes to indicate when markerless display is preferred or not.
    */
    get isMarkerlessDisplayPreferred(): boolean;
    static ngAcceptInputType_isMarkerlessDisplayPreferred: boolean | string;
    /**
     * The final value of this series.
    */
    get finalValue(): number;
    set finalValue(v: number);
    static ngAcceptInputType_finalValue: number | string;
    /**
     * The percent change from the beginning to the end of this series.
    */
    get percentChange(): number;
    set percentChange(v: number);
    static ngAcceptInputType_percentChange: number | string;
    /**
     * Gets the text that is displayed for the Open label in the tooltip.
    */
    get actualOpenLabel(): string;
    /**
     * Gets the text that is displayed for the Close label in the tooltip.
    */
    get actualCloseLabel(): string;
    /**
     * Gets the text that is displayed for the High label in the tooltip.
    */
    get actualHighLabel(): string;
    /**
     * Gets the text that is displayed for the Low label in the tooltip.
    */
    get actualLowLabel(): string;
    /**
     * Gets the text that is displayed for the Volume label in the tooltip.
    */
    get actualVolumeLabel(): string;
    /**
     * Gets the text that is displayed for the Value label in the tooltip.
    */
    get actualValueLabel(): string;
    /**
     * Gets the text that is displayed for the Value label in the tooltip.
    */
    get actualRadiusLabel(): string;
    get opacity(): number;
    set opacity(v: number);
    static ngAcceptInputType_opacity: number | string;
    get visibility(): Visibility;
    set visibility(v: Visibility);
    static ngAcceptInputType_visibility: Visibility | string;
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Gets the brush for tooltip labels.

*/
    resolveTooltipBrush(): string;
    getItemValue(item: any, memberPathName: string): any;
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    *
    * ```ts
    * let index: number = this.series.getExactItemIndex({x:.5,y:.5});
    * ```
    */
    getExactItemIndex(world: IgPoint): number;
    /**
     * Gets the item index associated with the specified world position
    
    *
    * ```ts
    * let index: number = this.series.getItemIndex({x:.5,y:.5});
    * ```
    */
    getItemIndex(world: IgPoint): number;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    *
    * ```ts
    * let item: number = this.series.getItem({x:.5,y:.5});
    * ```
    */
    getItem(world: IgPoint): any;
    getPreviousOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getNextOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    *
    * ```ts
    * let box: IgxRect = this.series.getSeriesValueBoundingBox({x:.8,y:.8});
    * ```
    */
    getSeriesValueBoundingBox(world: IgPoint): IgRect;
    /**
     * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinates for which to get a value marker bounding box for
    *
    * ```ts
    * let box: IgxRect = this.series.getSeriesValueMarkerBoundingBox({x:.8,y:.8});
    * ```
    */
    getSeriesValueMarkerBoundingBox(world: IgPoint): IgRect;
    getSeriesHighValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesLowValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesLowValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesValuePositionFromSeriesPixel(mouse: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesValueFromSeriesPixel(mouse: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    *
    * ```ts
    * let span: number = this.series.getItemSpan();
    * ```
    */
    getItemSpan(): number;
    /**
     * Gets the data values of each axis associated with the specified value type. For example, if you specify
     * mode as Maximum then it will return the maximum numerical value for each axis. For non-numerical axes it
     * will return NaN.
    
    * @param mode  * The type of value desired from the series axes.
    */
    getSeriesValueType(mode: ValueLayerValueMode): number[];
    getSeriesValueTypePosition(mode: ValueLayerValueMode): IgPoint;
    getSeriesValueTypePositionFromValue(values: number[]): IgPoint;
    /**
     * Hides any internal tooltips presented by the series, if any.
    
    */
    hideToolTips(): void;
    /**
     * Hides any internal tooltips presented by the series, if any.
    
    */
    hideToolTipsImmediate(): void;
    /**
     * Converts a point from coordinates within the series plot area to a world position within axis space.
    
    * @param seriesPoint  * The pixel location within the plot area of the series.
    *
    * ```ts
    * this.series.toWorldPosition({x:500,y:500});
    * ```
    */
    toWorldPosition(seriesPoint: IgPoint): IgPoint;
    /**
     * Converts a point from world coordinates to coordinates within the viewport of the series.
    
    * @param world  * The world position from which to convert.
    *
    * ```ts
    * let pt: IgxPoint = this.series.fromWorldPosition({x:.5,y:.5});
    * ```
    */
    fromWorldPosition(world: IgPoint): IgPoint;
    /**
     * Requests that the provided item should be brought into view if possible.
    
    * @param item  * The item to attempt to bring into view.
    *
    * ```ts
    * this.series.scrollIntoView(dataItem);
    * ```
    */
    scrollIntoView(item: any): boolean;
    /**
     * Renders the series.
    
    * @param animate  * True if the change should be animated.
    *
    * ```ts
    * this.series.renderSeries(true);
    * ```
    */
    renderSeries(animate: boolean): void;
    /**
     * Gets the effective viewport, adjusted to account for margins and other factors.
    
    */
    getEffectiveViewport(): IgRect;
    /**
     * Removes all alternate views of this series.
    
    */
    removeAllAlternateViews(): void;
    /**
     * Removes an alternate view of this series.
    
    * @param viewIdentifier  * The string identifier for the view to remove.
    */
    removeAlternateView(viewIdentifier: string): void;
    /**
     * Called to notify about changes to indexed-based properties, e.g. Brushes, Outlines, MarkerBrushes, MarkerOutlines and refresh series
    
    */
    notifyIndexedPropertiesChanged(): void;
    /**
     * Notifies the series that a visual property has changed, requiring a visual update.
    
    */
    notifyVisualPropertiesChanged(): void;
    /**
     * Replays the assigned transition in animation, if any.
    
    *
    * ```ts
    * this.series.replayTransitionIn();
    * ```
    */
    replayTransitionIn(): void;
    /**
     * Call to null out the axes of the series;
    
    */
    removeAxes(): void;
    /**
     * Simulates a pointer hover over the series surface.
    
    * @param point  * The pointer position relative to the series viewport over which to hover.
    *
    * When tooltips are enabled, `SimulateHover` can be used to automatically display the tooltip over a particular series item.
    *
    * ```ts
    * this.series.simulateHover({x:250,y:250});
    * ```
    */
    simulateHover(point: IgPoint): void;
    /**
     * Called when this series' Style is updated.
    
    */
    styleUpdated(): void;
    setNegativeColors(negativeBrush: string, negativeOutline: string): void;
    /**
     * Moves the cursor point to the provided world position. Some series may react to the current cursor position.
    
    * @param point  * The cursor point, in world coordinates.
    *
    * `MoveCursorPoint` can be used on annotation layers to programitically show the annotation at the given point.
    *
    * ```ts
    * this.crosshair.moveCursorPoint({x:.5,y:.5});
    * ```
    */
    moveCursorPoint(point: IgPoint): void;
    private _renderRequested;
    /**
     * This event is raised every time a render has been requested from a series.
    */
    get renderRequested(): EventEmitter<{
        sender: any;
        args: IgxRenderRequestedEventArgs;
    }>;
    protected _zoneRunner: (act: () => void) => void;
    protected _runInZone(act: () => void): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxSeriesComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxSeriesComponent, "ng-component", never, { "name": "name"; "legend": "legend"; "dataSource": "dataSource"; "tooltipTemplate": "tooltipTemplate"; "tooltipContainerTemplate": "tooltipContainerTemplate"; "legendItemVisibility": "legendItemVisibility"; "legendItemBadgeTemplate": "legendItemBadgeTemplate"; "actualLegendItemBadgeTemplate": "actualLegendItemBadgeTemplate"; "actualLegendItemBadgeOutline": "actualLegendItemBadgeOutline"; "actualLegendItemBadgeBrush": "actualLegendItemBadgeBrush"; "legendItemBadgeShape": "legendItemBadgeShape"; "legendItemBadgeMode": "legendItemBadgeMode"; "legendItemTemplate": "legendItemTemplate"; "discreteLegendItemTemplate": "discreteLegendItemTemplate"; "transitionEasingFunction": "transitionEasingFunction"; "transitionInEasingFunction": "transitionInEasingFunction"; "transitionDuration": "transitionDuration"; "actualResolution": "actualResolution"; "resolution": "resolution"; "visibleRangeMarginTop": "visibleRangeMarginTop"; "visibleRangeMarginBottom": "visibleRangeMarginBottom"; "visibleRangeMarginLeft": "visibleRangeMarginLeft"; "visibleRangeMarginRight": "visibleRangeMarginRight"; "title": "title"; "brush": "brush"; "actualBrush": "actualBrush"; "outline": "outline"; "actualOutline": "actualOutline"; "lineJoin": "lineJoin"; "thickness": "thickness"; "actualThickness": "actualThickness"; "dashArray": "dashArray"; "actualHighlightingMode": "actualHighlightingMode"; "actualHighlightingFadeOpacity": "actualHighlightingFadeOpacity"; "highlightingFadeOpacity": "highlightingFadeOpacity"; "isActualLegendFinancial": "isActualLegendFinancial"; "isComponentHighlightingModeIgnored": "isComponentHighlightingModeIgnored"; "isHighlightingEnabled": "isHighlightingEnabled"; "shouldHideAutoCallouts": "shouldHideAutoCallouts"; "isDropShadowEnabled": "isDropShadowEnabled"; "shadowBlur": "shadowBlur"; "shadowColor": "shadowColor"; "useSingleShadow": "useSingleShadow"; "shadowOffsetX": "shadowOffsetX"; "shadowOffsetY": "shadowOffsetY"; "areaFillOpacity": "areaFillOpacity"; "actualAreaFillOpacity": "actualAreaFillOpacity"; "markerFillOpacity": "markerFillOpacity"; "actualMarkerFillOpacity": "actualMarkerFillOpacity"; "isDefaultToolTipSelected": "isDefaultToolTipSelected"; "showDefaultTooltip": "showDefaultTooltip"; "visibleRangeMode": "visibleRangeMode"; "outlineMode": "outlineMode"; "transitionInDuration": "transitionInDuration"; "transitionInSpeedType": "transitionInSpeedType"; "lineCap": "lineCap"; "mouseOverEnabled": "mouseOverEnabled"; "coercionMethods": "coercionMethods"; "expectFunctions": "expectFunctions"; "hitTestMode": "hitTestMode"; "actualHitTestMode": "actualHitTestMode"; "finalValue": "finalValue"; "percentChange": "percentChange"; "opacity": "opacity"; "visibility": "visibility"; }, { "renderRequested": "renderRequested"; }, never, never>;
}
