import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { StochRSIIndicator } from "./StochRSIIndicator";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent StochRSI indicator series.
 * Default required members: Close
*
* `StochRSIIndicator` or Stochastic Relative Strength IndexI Indicator (SRSI) measures when a security is overbought or oversold within a specified period of time. The values range from 0 to 1. The StochRSI Indicator is calculated by applying the Stochastic Oscillator formula to RelativeStrengthIndexIndicator (RSI) data.
*
* Using this indicator requires setting the `CloseMemberPath`.
*
* ```html
* <igx-data-chart
*     width=500px
*     height=500px
*     [dataSource]="data" >
*     <igx-ordinal-time-x-axis
*         dateTimeMemberPath="TimeStamp"
*         #xAxis>
*       </igx-ordinal-time-x-axis>
*     <igx-numeric-y-axis
*        #yAxis></igx-numeric-y-axis>
*     <igx-stoch-rsi-indicator
*        [xAxis]="xAxis"
*        [yAxis]="yAxis"
*        closeMemberPath="Close">
*      </igx-stoch-rsi-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxStochRSIIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export declare class IgxStochRSIIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    protected createImplementation(): StochRSIIndicator;
    /**
                                 * @hidden
                                 */
    get i(): StochRSIIndicator;
    constructor();
    /**
     * Gets or sets the moving average period for the current StochRSIIndicator object.
     * The typical, and initial, value for StochRSI periods is 14.
    *
    * ```html
    * <igx-data-chart
    *     width=500px
    *     height=500px
    *     [dataSource]="data" >
    *     <igx-ordinal-time-x-axis
    *         dateTimeMemberPath="TimeStamp"
    *         #xAxis>
    *       </igx-ordinal-time-x-axis>
    *     <igx-numeric-y-axis
    *        #yAxis></igx-numeric-y-axis>
    *     <igx-stoch-rsi-indicator
    *        [xAxis]="xAxis"
    *        [yAxis]="yAxis"
    *        closeMemberPath="Close"
    *        period=10>
    *      </igx-stoch-rsi-indicator>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.period = 10;
    * ```
    */
    get period(): number;
    set period(v: number);
    static ngAcceptInputType_period: number | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxStochRSIIndicatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxStochRSIIndicatorComponent, "igx-stoch-rsi-indicator", never, { "period": "period"; }, {}, never, never>;
}
