import { NumericScaleMode } from "./NumericScaleMode";
import { IgxNumericAxisBaseComponent } from "./igx-numeric-axis-base-component";
import { StraightNumericAxisBase } from "./StraightNumericAxisBase";
import * as i0 from "@angular/core";
/**
 * Defines a set of basic methods and properties used to create a StraightNumeric axis.
*/
export declare abstract class IgxStraightNumericAxisBaseComponent extends IgxNumericAxisBaseComponent {
    /**
                                 * @hidden
                                 */
    get i(): StraightNumericAxisBase;
    constructor();
    /**
     * Gets or sets the axis scale mode.
    *
    * `ScaleMode` can be used on numeric axes to allow scaling data values using built-in scalers. The available scalers are linear or logarithmic.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis
    *         scaleMode="logarithmic">
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value">
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.yAxis.scaleMode = NumericScaleMode.Logarithmic;
    * ```
    */
    get scaleMode(): NumericScaleMode;
    set scaleMode(v: NumericScaleMode);
    static ngAcceptInputType_scaleMode: NumericScaleMode | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxStraightNumericAxisBaseComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxStraightNumericAxisBaseComponent, "ng-component", never, { "scaleMode": "scaleMode"; }, {}, never, never>;
}
