import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { TRIXIndicator } from "./TRIXIndicator";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent TRIX indicator series.
 * Default required members: Close
*
* The `TRIXIndicator` class specify the series as Trix Indicator series.
*
* ```html
* <igx-data-chart
*     [dataSource]="data">
* 	<igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
* 	<igx-trix-indicator
*         #series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         highMemberPath="high"
* 		lowMemberPath="low"
* 		volumeMemberPath="volume">
*     </igx-trix-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxTrixIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export declare class IgxTRIXIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    protected createImplementation(): TRIXIndicator;
    /**
                                 * @hidden
                                 */
    get i(): TRIXIndicator;
    constructor();
    /**
     * Gets or sets the moving average period for the current TRIXIndicator object.
     * The typical, and initial, value for TRIX periods is 15.
    *
    * The `Period` property is used for moving average period of the current TRIXIndicator object.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    * 	<igx-category-x-axis
    * 		label="label"
    * 		#xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    * 		#yAxis>
    *     </igx-numeric-y-axis>
    * 	<igx-trix-indicator
    *         #series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         highMemberPath="high"
    * 		lowMemberPath="low"
    * 		volumeMemberPath="volume"
    * 		period="7">
    *     </igx-trix-indicator>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.period = 30;
    * ```
    */
    get period(): number;
    set period(v: number);
    static ngAcceptInputType_period: number | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxTRIXIndicatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxTRIXIndicatorComponent, "igx-trix-indicator", never, { "period": "period"; }, {}, never, never>;
}
