import { ValueLayerValueMode } from "./ValueLayerValueMode";
import { IgxSeriesComponent } from "./igx-series-component";
import { IgxAxisComponent } from "./igx-axis-component";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { ValueLayer } from "./ValueLayer";
import * as i0 from "@angular/core";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
export declare class IgxValueLayerComponent extends IgxAnnotationLayerComponent {
    protected createImplementation(): ValueLayer;
    /**
                                 * @hidden
                                 */
    get i(): ValueLayer;
    constructor();
    /**
     * Gets whether the series is an crosshair annotation layer.
    */
    get isAnnotationValueLayer(): boolean;
    static ngAcceptInputType_isAnnotationValueLayer: boolean | string;
    /**
     * Gets or sets the value mode for the overlay.
    */
    get valueMode(): ValueLayerValueMode;
    set valueMode(v: ValueLayerValueMode);
    static ngAcceptInputType_valueMode: ValueLayerValueMode | string;
    /**
     * Gets or sets the color to use for the horizontal line. Leave null for an automatic value.
    */
    get horizontalLineStroke(): string;
    set horizontalLineStroke(v: string);
    /**
     * Gets or sets the color to use for vertical line. Leave null for an automatic value.
    */
    get verticalLineStroke(): string;
    set verticalLineStroke(v: string);
    /**
     * Gets or sets the name of the series to target this annotation to. If null, this annotation targets all series simultaneously.
    */
    get targetSeriesName(): string;
    set targetSeriesName(v: string);
    /**
     * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
    */
    get targetSeries(): IgxSeriesComponent;
    set targetSeries(v: IgxSeriesComponent);
    /**
     * Gets or sets the name of the axis to target this annotation to. If null, this annotation targets all axis simultaneously.
    */
    get targetAxisName(): string;
    set targetAxisName(v: string);
    /**
     * Gets or sets the axis to target this annotation to. If null, this annotation targets all value axis simultaneously.
    */
    get targetAxis(): IgxAxisComponent;
    set targetAxis(v: IgxAxisComponent);
    /**
     * Gets or sets whether to use value interpolation when drawing a line through the best value for the cursor position.
    */
    get useInterpolation(): boolean;
    set useInterpolation(v: boolean);
    static ngAcceptInputType_useInterpolation: boolean | string;
    /**
     * Gets or sets whether to draw annotations over the axes where the crosshair meets with them.
    */
    get isAxisAnnotationEnabled(): boolean;
    set isAxisAnnotationEnabled(v: boolean);
    static ngAcceptInputType_isAxisAnnotationEnabled: boolean | string;
    /**
     * Gets or sets the color to use for the x axis annotation text. Leave unset for an automatic value.
    */
    get xAxisAnnotationTextColor(): string;
    set xAxisAnnotationTextColor(v: string);
    /**
     * Gets or sets the color to use for the x axis annotation backing. Leave unset for an automatic value.
    */
    get xAxisAnnotationBackground(): string;
    set xAxisAnnotationBackground(v: string);
    /**
     * Gets or sets the corner radius to use for the x axis annotation backing. Leave unset for an automatic value.
    */
    get xAxisAnnotationBackgroundCornerRadius(): number;
    set xAxisAnnotationBackgroundCornerRadius(v: number);
    static ngAcceptInputType_xAxisAnnotationBackgroundCornerRadius: number | string;
    /**
     * Gets or sets the precision to use displaying values for interpolated crosshair positions.
    */
    get xAxisAnnotationInterpolatedValuePrecision(): number;
    set xAxisAnnotationInterpolatedValuePrecision(v: number);
    static ngAcceptInputType_xAxisAnnotationInterpolatedValuePrecision: number | string;
    /**
     * Gets or sets the color to use for the x axis annotation outline. Leave unset for an automatic value.
    */
    get xAxisAnnotationOutline(): string;
    set xAxisAnnotationOutline(v: string);
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    get xAxisAnnotationPaddingLeft(): number;
    set xAxisAnnotationPaddingLeft(v: number);
    static ngAcceptInputType_xAxisAnnotationPaddingLeft: number | string;
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    get xAxisAnnotationPaddingTop(): number;
    set xAxisAnnotationPaddingTop(v: number);
    static ngAcceptInputType_xAxisAnnotationPaddingTop: number | string;
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    get xAxisAnnotationPaddingRight(): number;
    set xAxisAnnotationPaddingRight(v: number);
    static ngAcceptInputType_xAxisAnnotationPaddingRight: number | string;
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    get xAxisAnnotationPaddingBottom(): number;
    set xAxisAnnotationPaddingBottom(v: number);
    static ngAcceptInputType_xAxisAnnotationPaddingBottom: number | string;
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    get yAxisAnnotationPaddingLeft(): number;
    set yAxisAnnotationPaddingLeft(v: number);
    static ngAcceptInputType_yAxisAnnotationPaddingLeft: number | string;
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    get yAxisAnnotationPaddingTop(): number;
    set yAxisAnnotationPaddingTop(v: number);
    static ngAcceptInputType_yAxisAnnotationPaddingTop: number | string;
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    get yAxisAnnotationPaddingRight(): number;
    set yAxisAnnotationPaddingRight(v: number);
    static ngAcceptInputType_yAxisAnnotationPaddingRight: number | string;
    /**
     * Gets or sets the padding to use withing the axis annotation callout. Leaving this NaN will use an automatic value related to the axis label margins.
    */
    get yAxisAnnotationPaddingBottom(): number;
    set yAxisAnnotationPaddingBottom(v: number);
    static ngAcceptInputType_yAxisAnnotationPaddingBottom: number | string;
    /**
     * Gets or sets the stroke thickness for the x axis annotation backing. Leave unset for an automatic value.
    */
    get xAxisAnnotationStrokeThickness(): number;
    set xAxisAnnotationStrokeThickness(v: number);
    static ngAcceptInputType_xAxisAnnotationStrokeThickness: number | string;
    /**
     * Gets or sets the color to use for the y axis annotation text. Leave unset for an automatic value.
    */
    get yAxisAnnotationTextColor(): string;
    set yAxisAnnotationTextColor(v: string);
    /**
     * Gets or sets the color to use for the y axis annotation backing. Leave unset for an automatic value.
    */
    get yAxisAnnotationBackground(): string;
    set yAxisAnnotationBackground(v: string);
    /**
     * Gets or sets the corner radius to use for the y axis annotation backing. Leave unset for an automatic value.
    */
    get yAxisAnnotationBackgroundCornerRadius(): number;
    set yAxisAnnotationBackgroundCornerRadius(v: number);
    static ngAcceptInputType_yAxisAnnotationBackgroundCornerRadius: number | string;
    /**
     * Gets or sets the precision to use displaying values for interpolated crosshair positions.
    */
    get yAxisAnnotationInterpolatedValuePrecision(): number;
    set yAxisAnnotationInterpolatedValuePrecision(v: number);
    static ngAcceptInputType_yAxisAnnotationInterpolatedValuePrecision: number | string;
    /**
     * Gets or sets the color to use for the y axis annotation outline. Leave unset for an automatic value.
    */
    get yAxisAnnotationOutline(): string;
    set yAxisAnnotationOutline(v: string);
    /**
     * Gets or sets the stroke thickness for the y axis annotation backing. Leave unset for an automatic value.
    */
    get yAxisAnnotationStrokeThickness(): number;
    set yAxisAnnotationStrokeThickness(v: number);
    static ngAcceptInputType_yAxisAnnotationStrokeThickness: number | string;
    /**
     * Gets or sets whether to skip unknown values when searching for series values.
    */
    get skipUnknownValues(): boolean;
    set skipUnknownValues(v: boolean);
    static ngAcceptInputType_skipUnknownValues: boolean | string;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxValueLayerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxValueLayerComponent, "igx-value-layer", never, { "valueMode": "valueMode"; "horizontalLineStroke": "horizontalLineStroke"; "verticalLineStroke": "verticalLineStroke"; "targetSeriesName": "targetSeriesName"; "targetSeries": "targetSeries"; "targetAxisName": "targetAxisName"; "targetAxis": "targetAxis"; "useInterpolation": "useInterpolation"; "isAxisAnnotationEnabled": "isAxisAnnotationEnabled"; "xAxisAnnotationTextColor": "xAxisAnnotationTextColor"; "xAxisAnnotationBackground": "xAxisAnnotationBackground"; "xAxisAnnotationBackgroundCornerRadius": "xAxisAnnotationBackgroundCornerRadius"; "xAxisAnnotationInterpolatedValuePrecision": "xAxisAnnotationInterpolatedValuePrecision"; "xAxisAnnotationOutline": "xAxisAnnotationOutline"; "xAxisAnnotationPaddingLeft": "xAxisAnnotationPaddingLeft"; "xAxisAnnotationPaddingTop": "xAxisAnnotationPaddingTop"; "xAxisAnnotationPaddingRight": "xAxisAnnotationPaddingRight"; "xAxisAnnotationPaddingBottom": "xAxisAnnotationPaddingBottom"; "yAxisAnnotationPaddingLeft": "yAxisAnnotationPaddingLeft"; "yAxisAnnotationPaddingTop": "yAxisAnnotationPaddingTop"; "yAxisAnnotationPaddingRight": "yAxisAnnotationPaddingRight"; "yAxisAnnotationPaddingBottom": "yAxisAnnotationPaddingBottom"; "xAxisAnnotationStrokeThickness": "xAxisAnnotationStrokeThickness"; "yAxisAnnotationTextColor": "yAxisAnnotationTextColor"; "yAxisAnnotationBackground": "yAxisAnnotationBackground"; "yAxisAnnotationBackgroundCornerRadius": "yAxisAnnotationBackgroundCornerRadius"; "yAxisAnnotationInterpolatedValuePrecision": "yAxisAnnotationInterpolatedValuePrecision"; "yAxisAnnotationOutline": "yAxisAnnotationOutline"; "yAxisAnnotationStrokeThickness": "yAxisAnnotationStrokeThickness"; "skipUnknownValues": "skipUnknownValues"; }, {}, never, never>;
}
