import { IgRect } from "igniteui-angular-core";
import { IgPoint } from "igniteui-angular-core";
import { IgxNumericXAxisComponent } from "./igx-numeric-x-axis-component";
import { IgxCategoryYAxisComponent } from "./igx-category-y-axis-component";
import { IgxAnchoredCategorySeriesComponent } from "./igx-anchored-category-series-component";
import { VerticalAnchoredCategorySeries } from "./VerticalAnchoredCategorySeries";
import * as i0 from "@angular/core";
/**
 * Represents a vertically laid out category based series.
*/
export declare abstract class IgxVerticalAnchoredCategorySeriesComponent extends IgxAnchoredCategorySeriesComponent {
    /**
                                 * @hidden
                                 */
    get i(): VerticalAnchoredCategorySeries;
    constructor();
    /**
     * Gets or sets the effective x-axis for the current CategorySeries object.
    */
    get xAxis(): IgxNumericXAxisComponent;
    set xAxis(v: IgxNumericXAxisComponent);
    /**
     * Gets or sets the effective y-axis for the current CategorySeries object.
    */
    get yAxis(): IgxCategoryYAxisComponent;
    set yAxis(v: IgxCategoryYAxisComponent);
    /**
     * Gets whether or not the current series is vertical series
    */
    get isVertical(): boolean;
    static ngAcceptInputType_isVertical: boolean | string;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    getCategoryWidth(): number;
    getNextOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getPreviousOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    /**
     * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinates for which to get a value marker bounding box for
    */
    getSeriesValueMarkerBoundingBox(world: IgPoint): IgRect;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    */
    getExactItemIndex(world: IgPoint): number;
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    */
    getItemIndex(world: IgPoint): number;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis: any): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxVerticalAnchoredCategorySeriesComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxVerticalAnchoredCategorySeriesComponent, "ng-component", never, { "xAxis": "xAxis"; "yAxis": "yAxis"; }, {}, never, never>;
}
